@@ -9,6 +9,7 @@ use Doctrine\DBAL\Platforms\MySQL\CollationMetadataProvider\CachingCollationMeta
 use Doctrine\DBAL\Platforms\MySQL\CollationMetadataProvider\ConnectionCollationMetadataProvider;
 use Doctrine\DBAL\Result;
 use Doctrine\DBAL\Types\Type;
+use Doctrine\Deprecations\Deprecation;
 
 use function array_change_key_case;
 use function array_shift;
@@ -31,9 +32,7 @@ use const CASE_LOWER;
  */
 class MySQLSchemaManager extends AbstractSchemaManager
 {
-    /**
-     * @see https://mariadb.com/kb/en/library/string-literals/#escape-sequences
-     */
+    /** @see https://mariadb.com/kb/en/library/string-literals/#escape-sequences */
     private const MARIADB_ESCAPE_SEQUENCES = [
         '\\0' => "\0",
         "\\'" => "'",
@@ -69,9 +68,18 @@ class MySQLSchemaManager extends AbstractSchemaManager
 
     /**
      * {@inheritDoc}
+     *
+     * @deprecated Use {@see introspectTable()} instead.
      */
     public function listTableDetails($name)
     {
+        Deprecation::trigger(
+            'doctrine/dbal',
+            'https://github.com/doctrine/dbal/pull/5595',
+            '%s is deprecated. Use introspectTable() instead.',
+            __METHOD__,
+        );
+
         return $this->doListTableDetails($name);
     }
 
@@ -198,7 +206,7 @@ class MySQLSchemaManager extends AbstractSchemaManager
                     preg_match(
                         '([A-Za-z]+\(([0-9]+),([0-9]+)\))',
                         $tableColumn['type'],
-                        $match
+                        $match,
                     ) === 1
                 ) {
                     $precision = $match[1];
@@ -368,7 +376,7 @@ class MySQLSchemaManager extends AbstractSchemaManager
             [
                 'onDelete' => $tableForeignKey['onDelete'],
                 'onUpdate' => $tableForeignKey['onUpdate'],
-            ]
+            ],
         );
     }
 
@@ -377,8 +385,8 @@ class MySQLSchemaManager extends AbstractSchemaManager
         return new MySQL\Comparator(
             $this->_platform,
             new CachingCollationMetadataProvider(
-                new ConnectionCollationMetadataProvider($this->_conn)
-            )
+                new ConnectionCollationMetadataProvider($this->_conn),
+            ),
         );
     }
 
@@ -415,12 +423,14 @@ SQL;
        c.COLLATION_NAME     AS collation
 FROM information_schema.COLUMNS c
     INNER JOIN information_schema.TABLES t
-        ON t.TABLE_SCHEMA = c.TABLE_SCHEMA
-        AND t.TABLE_NAME = c.TABLE_NAME
+        ON t.TABLE_NAME = c.TABLE_NAME
 SQL;
 
-        $conditions = ['c.TABLE_SCHEMA = ?', "t.TABLE_TYPE = 'BASE TABLE'"];
-        $params     = [$databaseName];
+        // The schema name is passed multiple times as a literal in the WHERE clause instead of using a JOIN condition
+        // in order to avoid performance issues on MySQL older than 8.0 and the corresponding MariaDB versions
+        // caused by https://bugs.mysql.com/bug.php?id=81347
+        $conditions = ['c.TABLE_SCHEMA = ?', 't.TABLE_SCHEMA = ?', "t.TABLE_TYPE = 'BASE TABLE'"];
+        $params     = [$databaseName, $databaseName];
 
         if ($tableName !== null) {
             $conditions[] = 't.TABLE_NAME = ?';
@@ -481,8 +491,7 @@ SQL;
 FROM information_schema.key_column_usage k /*!50116
 INNER JOIN information_schema.referential_constraints c
 ON c.CONSTRAINT_NAME = k.CONSTRAINT_NAME
-AND c.TABLE_NAME = k.TABLE_NAME
-AND c.CONSTRAINT_SCHEMA = k.TABLE_SCHEMA */
+AND c.TABLE_NAME = k.TABLE_NAME */
 SQL;
 
         $conditions = ['k.TABLE_SCHEMA = ?'];
@@ -495,7 +504,14 @@ SQL;
 
         $conditions[] = 'k.REFERENCED_COLUMN_NAME IS NOT NULL';
 
-        $sql .= ' WHERE ' . implode(' AND ', $conditions) . ' ORDER BY k.ORDINAL_POSITION';
+        $sql .= ' WHERE ' . implode(' AND ', $conditions)
+            // The schema name is passed multiple times in the WHERE clause instead of using a JOIN condition
+            // in order to avoid performance issues on MySQL older than 8.0 and the corresponding MariaDB versions
+            // caused by https://bugs.mysql.com/bug.php?id=81347.
+            // Use a string literal for the database name since the internal PDO SQL parser
+            // cannot recognize parameter placeholders inside conditional comments
+            . ' /*!50116 AND c.CONSTRAINT_SCHEMA = ' . $this->_conn->quote($databaseName) . ' */'
+            . ' ORDER BY k.ORDINAL_POSITION';
 
         return $this->_conn->executeQuery($sql, $params);
     }
@@ -551,9 +567,7 @@ SQL;
         return $tableOptions;
     }
 
-    /**
-     * @return string[]|true[]
-     */
+    /** @return string[]|true[] */
     private function parseCreateOptions(?string $string): array
     {
         $options = [];
