@@ -37,7 +37,7 @@ class GuidType extends StringType
             'doctrine/dbal',
             'https://github.com/doctrine/dbal/pull/5509',
             '%s is deprecated.',
-            __METHOD__
+            __METHOD__,
         );
 
         return ! $platform->hasNativeGuidType();
