@@ -12,9 +12,7 @@ use Doctrine\DBAL\Platforms\OraclePlatform;
 use Doctrine\DBAL\Schema\AbstractSchemaManager;
 use Doctrine\DBAL\Schema\OracleSchemaManager;
 
-/**
- * @extends AbstractDriverTest<OraclePlatform>
- */
+/** @extends AbstractDriverTest<OraclePlatform> */
 class AbstractOracleDriverTest extends AbstractDriverTest
 {
     protected function createDriver(): Driver
@@ -31,7 +29,7 @@ class AbstractOracleDriverTest extends AbstractDriverTest
     {
         return new OracleSchemaManager(
             $connection,
-            $this->createPlatform()
+            $this->createPlatform(),
         );
     }
 
