@@ -11,9 +11,7 @@ use function strtolower;
 
 class RenameColumnTest extends FunctionalTestCase
 {
-    /**
-     * @dataProvider columnNameProvider
-     */
+    /** @dataProvider columnNameProvider */
     public function testColumnPositionRetainedAfterRenaming(string $columnName, string $newColumnName): void
     {
         $table = new Table('test_rename');
@@ -27,18 +25,16 @@ class RenameColumnTest extends FunctionalTestCase
 
         $sm         =  $this->connection->createSchemaManager();
         $comparator = new Comparator();
-        $diff       = $comparator->diffTable($sm->listTableDetails('test_rename'), $table);
+        $diff       = $comparator->diffTable($sm->introspectTable('test_rename'), $table);
 
         self::assertNotFalse($diff);
         $sm->alterTable($diff);
 
-        $table = $sm->listTableDetails('test_rename');
+        $table = $sm->introspectTable('test_rename');
         self::assertSame([strtolower($newColumnName), 'c2'], array_keys($table->getColumns()));
     }
 
-    /**
-     * @return iterable<array{string}>
-     */
+    /** @return iterable<array{string}> */
     public static function columnNameProvider(): iterable
     {
         yield ['c1', 'c1_x'];
