@@ -61,18 +61,14 @@ class PortabilityTest extends FunctionalTestCase
         self::assertSame($expected, array_keys($row));
     }
 
-    /**
-     * @return iterable<string, array{int, list<string>}>
-     */
+    /** @return iterable<string, array{int, list<string>}> */
     public static function caseProvider(): iterable
     {
         yield 'lower' => [ColumnCase::LOWER, ['test_int', 'test_string', 'test_null']];
         yield 'upper' => [ColumnCase::UPPER, ['TEST_INT', 'TEST_STRING', 'TEST_NULL']];
     }
 
-    /**
-     * @param array<int, array<string, mixed>> $rows
-     */
+    /** @param array<int, array<string, mixed>> $rows */
     private function assertFetchResultRows(array $rows): void
     {
         self::assertCount(2, $rows);
@@ -81,14 +77,12 @@ class PortabilityTest extends FunctionalTestCase
         }
     }
 
-    /**
-     * @param array<string, mixed> $row
-     */
+    /** @param array<string, mixed> $row */
     public function assertFetchResultRow(array $row): void
     {
         self::assertThat($row['test_int'], self::logicalOr(
             self::equalTo(1),
-            self::equalTo(2)
+            self::equalTo(2),
         ));
 
         self::assertArrayHasKey('test_string', $row, 'Case should be lowered.');
@@ -112,9 +106,7 @@ class PortabilityTest extends FunctionalTestCase
         self::assertEquals($expected, $result->fetchFirstColumn());
     }
 
-    /**
-     * @return iterable<string, array<int, mixed>>
-     */
+    /** @return iterable<string, array<int, mixed>> */
     public static function fetchColumnProvider(): iterable
     {
         return [
@@ -139,6 +131,12 @@ class PortabilityTest extends FunctionalTestCase
         self::assertSame([null, null], $column);
     }
 
+    public function testGetDatabaseName(): void
+    {
+        $this->connectWithPortability(Connection::PORTABILITY_EMPTY_TO_NULL, 0);
+        self::assertNotNull($this->connection->getDatabase());
+    }
+
     private function connectWithPortability(int $mode, int $case): void
     {
         // closing the default connection prior to 4.0.0 to prevent connection leak
@@ -148,8 +146,8 @@ class PortabilityTest extends FunctionalTestCase
         $configuration->setMiddlewares(
             array_merge(
                 $configuration->getMiddlewares(),
-                [new Middleware($mode, $case)]
-            )
+                [new Middleware($mode, $case)],
+            ),
         );
 
         $this->connection = DriverManager::getConnection($this->connection->getParams(), $configuration);
