@@ -33,9 +33,7 @@ final class ComparatorTest extends FunctionalTestCase
         $this->comparator    = $this->schemaManager->createComparator();
     }
 
-    /**
-     * @dataProvider lobColumnProvider
-     */
+    /** @dataProvider lobColumnProvider */
     public function testLobLengthIncrementWithinLimit(string $type, int $length): void
     {
         $table = $this->createLobTable($type, $length - 1);
@@ -44,19 +42,17 @@ final class ComparatorTest extends FunctionalTestCase
         self::assertFalse(ComparatorTestUtils::diffFromActualToDesiredTable(
             $this->schemaManager,
             $this->comparator,
-            $table
+            $table,
         ));
 
         self::assertFalse(ComparatorTestUtils::diffFromDesiredToActualTable(
             $this->schemaManager,
             $this->comparator,
-            $table
+            $table,
         ));
     }
 
-    /**
-     * @dataProvider lobColumnProvider
-     */
+    /** @dataProvider lobColumnProvider */
     public function testLobLengthIncrementOverLimit(string $type, int $length): void
     {
         $table = $this->createLobTable($type, $length);
@@ -64,9 +60,7 @@ final class ComparatorTest extends FunctionalTestCase
         ComparatorTestUtils::assertDiffNotEmpty($this->connection, $this->comparator, $table);
     }
 
-    /**
-     * @return iterable<array{string,int}>
-     */
+    /** @return iterable<array{string,int}> */
     public static function lobColumnProvider(): iterable
     {
         yield [Types::BLOB, AbstractMySQLPlatform::LENGTH_LIMIT_TINYBLOB];
@@ -78,9 +72,7 @@ final class ComparatorTest extends FunctionalTestCase
         yield [Types::TEXT, AbstractMySQLPlatform::LENGTH_LIMIT_MEDIUMTEXT];
     }
 
-    /**
-     * @throws Exception
-     */
+    /** @throws Exception */
     private function createLobTable(string $type, int $length): Table
     {
         $table = new Table('comparator_test');
@@ -91,9 +83,7 @@ final class ComparatorTest extends FunctionalTestCase
         return $table;
     }
 
-    /**
-     * @throws Exception
-     */
+    /** @throws Exception */
     private function increaseLobLength(Table $table): void
     {
         $column = $table->getColumn('lob');
@@ -108,13 +98,13 @@ final class ComparatorTest extends FunctionalTestCase
         self::assertFalse(ComparatorTestUtils::diffFromActualToDesiredTable(
             $this->schemaManager,
             $this->comparator,
-            $table
+            $table,
         ));
 
         self::assertFalse(ComparatorTestUtils::diffFromDesiredToActualTable(
             $this->schemaManager,
             $this->comparator,
-            $table
+            $table,
         ));
     }
 
@@ -147,13 +137,13 @@ final class ComparatorTest extends FunctionalTestCase
         self::assertFalse(ComparatorTestUtils::diffFromActualToDesiredTable(
             $this->schemaManager,
             $this->comparator,
-            $table
+            $table,
         ));
 
         self::assertFalse(ComparatorTestUtils::diffFromDesiredToActualTable(
             $this->schemaManager,
             $this->comparator,
-            $table
+            $table,
         ));
     }
 
