@@ -22,17 +22,6 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
         return $platform instanceof OraclePlatform;
     }
 
-    public function testRenameTable(): void
-    {
-        $this->createTestTable('list_tables_test');
-        $this->dropTableIfExists('list_tables_test_new_name');
-        $this->schemaManager->renameTable('list_tables_test', 'list_tables_test_new_name');
-
-        $tables = $this->schemaManager->listTables();
-
-        self::assertHasTable($tables);
-    }
-
     /**
      * Oracle currently stores VARBINARY columns as RAW (fixed-size)
      */
@@ -89,7 +78,7 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $offlinePrimaryTable->addColumn(
             '"Id"',
             'integer',
-            ['autoincrement' => true, 'comment' => 'Explicit casing.']
+            ['autoincrement' => true, 'comment' => 'Explicit casing.'],
         );
         $offlinePrimaryTable->addColumn('select', 'integer', ['comment' => 'Reserved keyword.']);
         $offlinePrimaryTable->addColumn('foo', 'integer', ['comment' => 'Implicit uppercasing.']);
@@ -111,7 +100,7 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
             ['"Fk"'],
             ['"Id"'],
             [],
-            '"Primary_Table_Fk"'
+            '"Primary_Table_Fk"',
         );
         $offlineForeignTable->setPrimaryKey(['id']);
 
@@ -121,8 +110,8 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $this->schemaManager->createTable($offlinePrimaryTable);
         $this->schemaManager->createTable($offlineForeignTable);
 
-        $onlinePrimaryTable = $this->schemaManager->listTableDetails($primaryTableName);
-        $onlineForeignTable = $this->schemaManager->listTableDetails($foreignTableName);
+        $onlinePrimaryTable = $this->schemaManager->introspectTable($primaryTableName);
+        $onlineForeignTable = $this->schemaManager->introspectTable($foreignTableName);
 
         $platform = $this->connection->getDatabasePlatform();
 
@@ -186,15 +175,15 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertTrue($onlineForeignTable->hasForeignKey('"Primary_Table_Fk"'));
         self::assertSame(
             $primaryTableName,
-            $onlineForeignTable->getForeignKey('"Primary_Table_Fk"')->getQuotedForeignTableName($platform)
+            $onlineForeignTable->getForeignKey('"Primary_Table_Fk"')->getQuotedForeignTableName($platform),
         );
         self::assertSame(
             ['"Fk"'],
-            $onlineForeignTable->getForeignKey('"Primary_Table_Fk"')->getQuotedLocalColumns($platform)
+            $onlineForeignTable->getForeignKey('"Primary_Table_Fk"')->getQuotedLocalColumns($platform),
         );
         self::assertSame(
             ['"Id"'],
-            $onlineForeignTable->getForeignKey('"Primary_Table_Fk"')->getQuotedForeignColumns($platform)
+            $onlineForeignTable->getForeignKey('"Primary_Table_Fk"')->getQuotedForeignColumns($platform),
         );
     }
 
@@ -231,7 +220,7 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->schemaManager->createIndex(
             new Index('id_pk_id_index', ['id'], true, true),
-            'list_table_indexes_pk_id_test'
+            'list_table_indexes_pk_id_test',
         );
 
         $tableIndexes = $this->schemaManager->listTableIndexes('list_table_indexes_pk_id_test');
@@ -261,7 +250,7 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
     public function testCreateAndListSequences(): void
     {
         self::markTestSkipped(
-            "Skipped for uppercase letters are contained in sequences' names. Fix the schema manager in 3.0."
+            "Skipped for uppercase letters are contained in sequences' names. Fix the schema manager in 3.0.",
         );
     }
 
@@ -275,7 +264,7 @@ class OracleSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $schemaManager = $this->connection->createSchemaManager();
 
-        $fromSchema = $schemaManager->createSchema();
+        $fromSchema = $schemaManager->introspectSchema();
         $toSchema   = clone $fromSchema;
 
         $toSchema->getTable('"tester"')->dropColumn('"name"');
