@@ -2,6 +2,7 @@
 
 namespace Doctrine\DBAL\Tests\Functional\Schema;
 
+use Doctrine\DBAL\Driver\ServerInfoAwareConnection;
 use Doctrine\DBAL\Exception\DatabaseObjectNotFoundException;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\PostgreSQLPlatform;
@@ -15,6 +16,8 @@ use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\Schema\View;
 use Doctrine\DBAL\Types\BlobType;
 use Doctrine\DBAL\Types\DecimalType;
+use Doctrine\DBAL\Types\IntegerType;
+use Doctrine\DBAL\Types\TextType;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
 use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
@@ -25,7 +28,9 @@ use function array_pop;
 use function array_unshift;
 use function assert;
 use function count;
+use function sprintf;
 use function strtolower;
+use function version_compare;
 
 class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 {
@@ -66,13 +71,13 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $createTableSQL = 'CREATE TABLE domain_type_test (id INT PRIMARY KEY, value MyMoney)';
         $this->connection->executeStatement($createTableSQL);
 
-        $table = $this->connection->getSchemaManager()->listTableDetails('domain_type_test');
+        $table = $this->connection->getSchemaManager()->introspectTable('domain_type_test');
         self::assertInstanceOf(DecimalType::class, $table->getColumn('value')->getType());
 
         Type::addType('MyMoney', MoneyType::class);
         $this->connection->getDatabasePlatform()->registerDoctrineTypeMapping('MyMoney', 'MyMoney');
 
-        $table = $this->connection->getSchemaManager()->listTableDetails('domain_type_test');
+        $table = $this->connection->getSchemaManager()->introspectTable('domain_type_test');
         self::assertInstanceOf(MoneyType::class, $table->getColumn('value')->getType());
     }
 
@@ -82,7 +87,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $column       = $autoincTable->addColumn('id', 'integer');
         $column->setAutoincrement(true);
         $this->dropAndCreateTable($autoincTable);
-        $autoincTable = $this->schemaManager->listTableDetails('autoinc_table');
+        $autoincTable = $this->schemaManager->introspectTable('autoinc_table');
 
         self::assertTrue($autoincTable->getColumn('id')->getAutoincrement());
     }
@@ -103,7 +108,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $tableFrom = new Table('autoinc_table_add');
         $tableFrom->addColumn('id', 'integer');
         $this->dropAndCreateTable($tableFrom);
-        $tableFrom = $this->schemaManager->listTableDetails('autoinc_table_add');
+        $tableFrom = $this->schemaManager->introspectTable('autoinc_table_add');
         self::assertFalse($tableFrom->getColumn('id')->getAutoincrement());
 
         $tableTo = new Table('autoinc_table_add');
@@ -122,7 +127,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         ], $sql);
 
         $this->schemaManager->alterTable($diff);
-        $tableFinal = $this->schemaManager->listTableDetails('autoinc_table_add');
+        $tableFinal = $this->schemaManager->introspectTable('autoinc_table_add');
         self::assertTrue($tableFinal->getColumn('id')->getAutoincrement());
     }
 
@@ -137,7 +142,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $column    = $tableFrom->addColumn('id', 'integer');
         $column->setAutoincrement(true);
         $this->dropAndCreateTable($tableFrom);
-        $tableFrom = $this->schemaManager->listTableDetails('autoinc_table_drop');
+        $tableFrom = $this->schemaManager->introspectTable('autoinc_table_drop');
         self::assertTrue($tableFrom->getColumn('id')->getAutoincrement());
 
         $tableTo = new Table('autoinc_table_drop');
@@ -149,11 +154,11 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         self::assertEquals(
             ['ALTER TABLE autoinc_table_drop ALTER id DROP DEFAULT'],
-            $platform->getAlterTableSQL($diff)
+            $platform->getAlterTableSQL($diff),
         );
 
         $this->schemaManager->alterTable($diff);
-        $tableFinal = $this->schemaManager->listTableDetails('autoinc_table_drop');
+        $tableFinal = $this->schemaManager->introspectTable('autoinc_table_drop');
         self::assertFalse($tableFinal->getColumn('id')->getAutoincrement());
     }
 
@@ -181,7 +186,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $tables = $this->schemaManager->listTables();
         self::assertNotNull($this->findTableByName($tables, 'nested.schematable'));
 
-        $nestedSchemaTable = $this->schemaManager->listTableDetails('nested.schematable');
+        $nestedSchemaTable = $this->schemaManager->introspectTable('nested.schematable');
         self::assertTrue($nestedSchemaTable->hasColumn('id'));
 
         $primaryKey = $nestedSchemaTable->getPrimaryKey();
@@ -195,6 +200,32 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertEquals('nested.schemarelated', $relatedFk->getForeignTableName());
     }
 
+    public function testListSameTableNameColumnsWithDifferentSchema(): void
+    {
+        $this->connection->executeStatement('CREATE SCHEMA another');
+        $table = new Table('table');
+        $table->addColumn('id', 'integer');
+        $table->addColumn('name', 'text');
+        $this->schemaManager->createTable($table);
+
+        $anotherSchemaTable = new Table('another.table');
+        $anotherSchemaTable->addColumn('id', 'text');
+        $anotherSchemaTable->addColumn('email', 'text');
+        $this->schemaManager->createTable($anotherSchemaTable);
+
+        $table = $this->schemaManager->listTableDetails('table');
+        $this->assertCount(2, $table->getColumns());
+        $this->assertTrue($table->hasColumn('id'));
+        $this->assertInstanceOf(IntegerType::class, $table->getColumn('id')->getType());
+        $this->assertTrue($table->hasColumn('name'));
+
+        $anotherSchemaTable = $this->schemaManager->listTableDetails('another.table');
+        $this->assertCount(2, $anotherSchemaTable->getColumns());
+        $this->assertTrue($anotherSchemaTable->hasColumn('id'));
+        $this->assertInstanceOf(TextType::class, $anotherSchemaTable->getColumn('id')->getType());
+        $this->assertTrue($anotherSchemaTable->hasColumn('email'));
+    }
+
     public function testReturnQuotedAssets(): void
     {
         $this->connection->executeStatement('DROP TABLE IF EXISTS dbal91_something');
@@ -207,14 +238,14 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
             . ' FOREIGN KEY( "table" ) REFERENCES dbal91_something ON UPDATE CASCADE;';
         $this->connection->executeStatement($sql);
 
-        $table = $this->schemaManager->listTableDetails('dbal91_something');
+        $table = $this->schemaManager->introspectTable('dbal91_something');
 
         self::assertEquals(
             [
                 'CREATE TABLE dbal91_something (id INT NOT NULL, "table" INT DEFAULT NULL, PRIMARY KEY(id))',
                 'CREATE INDEX IDX_A9401304ECA7352B ON dbal91_something ("table")',
             ],
-            $this->connection->getDatabasePlatform()->getCreateTableSQL($table)
+            $this->connection->getDatabasePlatform()->getCreateTableSQL($table),
         );
     }
 
@@ -230,7 +261,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
                 'test_create_fk2',
                 ['id'],
                 'foreign_key_test' . $i . '_fk',
-                ['onDelete' => $fkOptions[$i]]
+                ['onDelete' => $fkOptions[$i]],
             );
         }
 
@@ -264,7 +295,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $testTable->setPrimaryKey(['id']);
         $this->dropAndCreateTable($testTable);
 
-        $databaseTable = $this->schemaManager->listTableDetails($testTable->getName());
+        $databaseTable = $this->schemaManager->introspectTable($testTable->getName());
 
         self::assertEquals('foo', $databaseTable->getColumn('def')->getDefault());
     }
@@ -282,7 +313,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $databaseTable = $this->schemaManager->listTableDetails($table->getName());
+        $databaseTable = $this->schemaManager->introspectTable($table->getName());
 
         $diff = $comparatorFactory($this->schemaManager)->diffTable($table, $databaseTable);
 
@@ -310,7 +341,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
      *
      * 1. The DBAL currently doesn't properly drop tables in the namespaces that need to be quoted
      *    (@see testListTableDetailsWhenCurrentSchemaNameQuoted()).
-     * 2. The schema returned by {@see AbstractSchemaManager::createSchema()} doesn't contain views, so
+     * 2. The schema returned by {@see AbstractSchemaManager::introspectSchema()} doesn't contain views, so
      *    {@see AbstractSchemaManager::dropSchemaObjects()} cannot drop the tables that have dependent views
      *    (@see testListTablesExcludesViews()).
      * 3. In the case of inheritance, PHPUnit runs the tests declared immediately in the test class
@@ -333,7 +364,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $schemaManager = $this->connection->createSchemaManager();
         $schemaManager->createSchemaObjects($schema);
 
-        $schema = $schemaManager->createSchema();
+        $schema = $schemaManager->introspectSchema();
         $schemaManager->dropSchemaObjects($schema);
 
         self::assertFalse($schemaManager->tablesExist(['test_autoincrement']));
@@ -384,7 +415,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($offlineTable);
 
-        $onlineTable = $this->schemaManager->listTableDetails('person');
+        $onlineTable = $this->schemaManager->introspectTable('person');
 
         $comparator = new Comparator();
 
@@ -460,9 +491,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertEquals('(-1)', $columns['col_string']->getDefault());
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function serialTypes(): iterable
     {
         return [
@@ -471,9 +500,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         ];
     }
 
-    /**
-     * @dataProvider serialTypes
-     */
+    /** @dataProvider serialTypes */
     public function testAutoIncrementCreatesSerialDataTypesWithoutADefaultValue(string $type): void
     {
         $tableName = 'test_serial_type_' . $type;
@@ -488,9 +515,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertNull($columns['id']->getDefault());
     }
 
-    /**
-     * @dataProvider serialTypes
-     */
+    /** @dataProvider serialTypes */
     public function testAutoIncrementCreatesSerialDataTypesWithoutADefaultValueEvenWhenDefaultIsSet(string $type): void
     {
         $tableName = 'test_serial_type_with_default_' . $type;
@@ -520,7 +545,7 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $column    = $tableFrom->addColumn('id', $from);
         $column->setAutoincrement(true);
         $this->dropAndCreateTable($tableFrom);
-        $tableFrom = $this->schemaManager->listTableDetails('autoinc_type_modification');
+        $tableFrom = $this->schemaManager->introspectTable('autoinc_type_modification');
         self::assertTrue($tableFrom->getColumn('id')->getAutoincrement());
 
         $tableTo = new Table('autoinc_type_modification');
@@ -531,17 +556,78 @@ class PostgreSQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertInstanceOf(TableDiff::class, $diff);
         self::assertSame(
             ['ALTER TABLE autoinc_type_modification ALTER id TYPE ' . $expected],
-            $this->connection->getDatabasePlatform()->getAlterTableSQL($diff)
+            $this->connection->getDatabasePlatform()->getAlterTableSQL($diff),
         );
 
         $this->schemaManager->alterTable($diff);
-        $tableFinal = $this->schemaManager->listTableDetails('autoinc_type_modification');
+        $tableFinal = $this->schemaManager->introspectTable('autoinc_type_modification');
         self::assertTrue($tableFinal->getColumn('id')->getAutoincrement());
     }
 
-    /**
-     * @return iterable<mixed[]>
-     */
+    public function testListTableColumnsOidConflictWithNonTableObject(): void
+    {
+        $wrappedConnection = $this->connection->getWrappedConnection();
+        assert($wrappedConnection instanceof ServerInfoAwareConnection);
+        if (version_compare($wrappedConnection->getServerVersion(), '10.0', '<')) {
+            self::markTestSkipped('Manually setting the Oid is not supported in 9.4');
+        }
+
+        $table = 'test_list_table_columns_oid_conflicts';
+        $this->connection->executeStatement(sprintf('CREATE TABLE IF NOT EXISTS %s(id INT NOT NULL)', $table));
+        $beforeColumns = $this->schemaManager->listTableColumns($table);
+        $this->assertArrayHasKey('id', $beforeColumns);
+
+        $this->connection->executeStatement('CREATE EXTENSION IF NOT EXISTS pg_prewarm');
+        $originalTableOid = $this->connection->fetchOne(
+            'SELECT oid FROM pg_class WHERE pg_class.relname = ?',
+            [$table],
+        );
+
+        $getConflictingOidSql = <<<'SQL'
+SELECT objid
+FROM pg_depend
+JOIN pg_extension as ex on ex.oid = pg_depend.refobjid
+WHERE ex.extname = 'pg_prewarm'
+ORDER BY objid
+LIMIT 1
+SQL;
+        $conflictingOid       = $this->connection->fetchOne($getConflictingOidSql);
+
+        $this->connection->executeStatement(
+            'UPDATE pg_attribute SET attrelid = ? WHERE attrelid = ?',
+            [$conflictingOid, $originalTableOid],
+        );
+        $this->connection->executeStatement(
+            'UPDATE pg_description SET objoid = ? WHERE objoid = ?',
+            [$conflictingOid, $originalTableOid],
+        );
+        $this->connection->executeStatement(
+            'UPDATE pg_class SET oid = ? WHERE oid = ?',
+            [$conflictingOid, $originalTableOid],
+        );
+
+        $afterColumns = $this->schemaManager->listTableColumns($table);
+
+        // revert to the database to original state prior to asserting result
+        $this->connection->executeStatement(
+            'UPDATE pg_attribute SET attrelid = ? WHERE attrelid = ?',
+            [$originalTableOid, $conflictingOid],
+        );
+        $this->connection->executeStatement(
+            'UPDATE pg_description SET objoid = ? WHERE objoid = ?',
+            [$originalTableOid, $conflictingOid],
+        );
+        $this->connection->executeStatement(
+            'UPDATE pg_class SET oid = ? WHERE oid = ?',
+            [$originalTableOid, $conflictingOid],
+        );
+        $this->connection->executeStatement(sprintf('DROP TABLE IF EXISTS %s', $table));
+        $this->connection->executeStatement('DROP EXTENSION IF EXISTS pg_prewarm');
+
+        $this->assertArrayHasKey('id', $afterColumns);
+    }
+
+    /** @return iterable<mixed[]> */
     public static function autoIncrementTypeMigrations(): iterable
     {
         foreach (ComparatorTestUtils::comparatorProvider() as $comparatorArguments) {
