@@ -41,16 +41,6 @@ class SqliteSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertFileDoesNotExist($path);
     }
 
-    public function testRenameTable(): void
-    {
-        $this->createTestTable('oldname');
-        $this->schemaManager->renameTable('oldname', 'newname');
-
-        $tables = $this->schemaManager->listTableNames();
-        self::assertContains('newname', $tables);
-        self::assertNotContains('oldname', $tables);
-    }
-
     public function createListTableColumns(): Table
     {
         $table = parent::createListTableColumns();
@@ -61,7 +51,7 @@ class SqliteSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
     public function testListForeignKeysFromExistingDatabase(): void
     {
-        $this->connection->executeStatement(<<<EOS
+        $this->connection->executeStatement(<<<'EOS'
 CREATE TABLE user (
     id INTEGER PRIMARY KEY AUTOINCREMENT,
     page INTEGER CONSTRAINT FK_1 REFERENCES page (key) DEFERRABLE INITIALLY DEFERRED,
@@ -69,8 +59,7 @@ CREATE TABLE user (
     log INTEGER,
     CONSTRAINT FK_3 FOREIGN KEY (log) REFERENCES log ON UPDATE SET NULL NOT DEFERRABLE
 )
-EOS
-        );
+EOS);
 
         $expected = [
             new ForeignKeyConstraint(
@@ -78,21 +67,21 @@ EOS
                 'page',
                 ['key'],
                 'FK_1',
-                ['onUpdate' => 'NO ACTION', 'onDelete' => 'NO ACTION', 'deferrable' => true, 'deferred' => true]
+                ['onUpdate' => 'NO ACTION', 'onDelete' => 'NO ACTION', 'deferrable' => true, 'deferred' => true],
             ),
             new ForeignKeyConstraint(
                 ['parent'],
                 'user',
                 ['id'],
                 null,
-                ['onUpdate' => 'NO ACTION', 'onDelete' => 'CASCADE', 'deferrable' => false, 'deferred' => false]
+                ['onUpdate' => 'NO ACTION', 'onDelete' => 'CASCADE', 'deferrable' => false, 'deferred' => false],
             ),
             new ForeignKeyConstraint(
                 ['log'],
                 'log',
                 [],
                 'FK_3',
-                ['onUpdate' => 'SET NULL', 'onDelete' => 'NO ACTION', 'deferrable' => false, 'deferred' => false]
+                ['onUpdate' => 'SET NULL', 'onDelete' => 'NO ACTION', 'deferrable' => false, 'deferred' => false],
             ),
         ];
 
@@ -134,7 +123,7 @@ EOS
 
     public function testListTableColumnsWithWhitespacesInTypeDeclarations(): void
     {
-        $sql = <<<SQL
+        $sql = <<<'SQL'
 CREATE TABLE dbal_1779 (
     foo VARCHAR (64) ,
     bar TEXT (100)
@@ -172,7 +161,7 @@ SQL;
         $this->connection->insert('test_pk_auto_increment', ['text' => '2']);
 
         $lastUsedIdAfterDelete = (int) $this->connection->fetchOne(
-            'SELECT id FROM test_pk_auto_increment WHERE text = "2"'
+            'SELECT id FROM test_pk_auto_increment WHERE text = "2"',
         );
 
         // with an empty table, non autoincrement rowid is always 1
@@ -189,7 +178,7 @@ SQL;
         $sm = $this->connection->getSchemaManager();
         $sm->createTable($table);
 
-        self::assertNull($sm->listTableDetails('own_column_comment')
+        self::assertNull($sm->introspectTable('own_column_comment')
             ->getColumn('col1')
             ->getComment());
     }
@@ -212,7 +201,7 @@ SQL;
 
         $schemaManager = $this->connection->createSchemaManager();
 
-        $table1 = $schemaManager->listTableDetails('nodes');
+        $table1 = $schemaManager->introspectTable('nodes');
         $table2 = clone $table1;
         $table2->addIndex(['name'], 'idx_name');
 
@@ -222,7 +211,7 @@ SQL;
 
         $schemaManager->alterTable($diff);
 
-        $table = $schemaManager->listTableDetails('nodes');
+        $table = $schemaManager->introspectTable('nodes');
         $index = $table->getIndex('idx_name');
         self::assertSame(['name'], $index->getColumns());
     }
@@ -258,7 +247,7 @@ SQL;
 
         $schemaManager = $this->connection->createSchemaManager();
 
-        $song        = $schemaManager->listTableDetails('song');
+        $song        = $schemaManager->introspectTable('song');
         $foreignKeys = $song->getForeignKeys();
         self::assertCount(2, $foreignKeys);
 
