@@ -14,6 +14,7 @@ use Doctrine\DBAL\Schema\ColumnDiff;
 use Doctrine\DBAL\Schema\Comparator;
 use Doctrine\DBAL\Schema\ForeignKeyConstraint;
 use Doctrine\DBAL\Schema\Index;
+use Doctrine\DBAL\Schema\SchemaDiff;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\Schema\UniqueConstraint;
@@ -28,9 +29,7 @@ use function implode;
 use function sprintf;
 use function str_repeat;
 
-/**
- * @template T of AbstractPlatform
- */
+/** @template T of AbstractPlatform */
 abstract class AbstractPlatformTestCase extends TestCase
 {
     /** @var T */
@@ -38,9 +37,7 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     private ?Type $backedUpType = null;
 
-    /**
-     * @return T
-     */
+    /** @return T */
     abstract public function createPlatform(): AbstractPlatform;
 
     protected function setUp(): void
@@ -72,17 +69,13 @@ abstract class AbstractPlatformTestCase extends TestCase
         self::assertEquals(str_repeat($c, 4), $this->platform->quoteSingleIdentifier($c));
     }
 
-    /**
-     * @dataProvider getReturnsForeignKeyReferentialActionSQL
-     */
+    /** @dataProvider getReturnsForeignKeyReferentialActionSQL */
     public function testReturnsForeignKeyReferentialActionSQL(string $action, string $expectedSQL): void
     {
         self::assertSame($expectedSQL, $this->platform->getForeignKeyReferentialActionSQL($action));
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function getReturnsForeignKeyReferentialActionSQL(): iterable
     {
         return [
@@ -127,17 +120,13 @@ abstract class AbstractPlatformTestCase extends TestCase
         self::assertTrue($this->platform->isCommentedDoctrineType($type));
     }
 
-    /**
-     * @dataProvider getIsCommentedDoctrineType
-     */
+    /** @dataProvider getIsCommentedDoctrineType */
     public function testIsCommentedDoctrineType(Type $type, bool $commented): void
     {
         self::assertSame($commented, $this->platform->isCommentedDoctrineType($type));
     }
 
-    /**
-     * @return mixed[]
-     */
+    /** @return mixed[] */
     public function getIsCommentedDoctrineType(): iterable
     {
         $this->setUp();
@@ -188,9 +177,7 @@ abstract class AbstractPlatformTestCase extends TestCase
         self::assertEquals($this->getGenerateTableWithMultiColumnUniqueIndexSql(), $sql);
     }
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     abstract public function getGenerateTableWithMultiColumnUniqueIndexSql(): array;
 
     public function testGeneratesIndexCreationSql(): void
@@ -199,7 +186,7 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertEquals(
             $this->getGenerateIndexSql(),
-            $this->platform->getCreateIndexSQL($indexDef, 'mytable')
+            $this->platform->getCreateIndexSQL($indexDef, 'mytable'),
         );
     }
 
@@ -310,60 +297,15 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         return sprintf(
             'ALTER TABLE test ADD CONSTRAINT constraint_fk FOREIGN KEY (fk_name) REFERENCES %s (id)',
-            $quotedForeignTable
+            $quotedForeignTable,
         );
     }
 
-    /**
-     * @return string[]
-     */
-    abstract public function getGenerateAlterTableSql(): array;
-
-    public function testGeneratesTableAlterationSql(): void
-    {
-        $expectedSql = $this->getGenerateAlterTableSql();
-
-        $table = new Table('mytable');
-        $table->addColumn('id', 'integer', ['autoincrement' => true]);
-        $table->addColumn('foo', 'integer');
-        $table->addColumn('bar', 'string');
-        $table->addColumn('bloo', 'boolean');
-        $table->setPrimaryKey(['id']);
-
-        $tableDiff                         = new TableDiff('mytable');
-        $tableDiff->fromTable              = $table;
-        $tableDiff->newName                = 'userlist';
-        $tableDiff->addedColumns['quota']  = new Column('quota', Type::getType('integer'), ['notnull' => false]);
-        $tableDiff->removedColumns['foo']  = new Column('foo', Type::getType('integer'));
-        $tableDiff->changedColumns['bar']  = new ColumnDiff(
-            'bar',
-            new Column(
-                'baz',
-                Type::getType('string'),
-                ['default' => 'def']
-            ),
-            ['type', 'notnull', 'default']
-        );
-        $tableDiff->changedColumns['bloo'] = new ColumnDiff(
-            'bloo',
-            new Column(
-                'bloo',
-                Type::getType('boolean'),
-                ['default' => false]
-            ),
-            ['type', 'notnull', 'default']
-        );
-
-        $sql = $this->platform->getAlterTableSQL($tableDiff);
-
-        self::assertEquals($expectedSql, $sql);
-    }
-
     public function testGetCustomColumnDeclarationSql(): void
     {
         self::assertEquals(
             'foo MEDIUMINT(6) UNSIGNED',
-            $this->platform->getColumnDeclarationSQL('foo', ['columnDefinition' => 'MEDIUMINT(6) UNSIGNED'])
+            $this->platform->getColumnDeclarationSQL('foo', ['columnDefinition' => 'MEDIUMINT(6) UNSIGNED']),
         );
     }
 
@@ -452,9 +394,9 @@ abstract class AbstractPlatformTestCase extends TestCase
             new Column(
                 'changed2',
                 Type::getType('string'),
-                []
+                [],
             ),
-            []
+            [],
         );
         $tableDiff->renamedColumns['renamed'] = new Column('renamed2', Type::getType('integer'), []);
 
@@ -478,18 +420,18 @@ abstract class AbstractPlatformTestCase extends TestCase
             'foo',
             new Column(
                 'foo',
-                Type::getType('string')
+                Type::getType('string'),
             ),
-            ['comment']
+            ['comment'],
         );
         $tableDiff->changedColumns['bar'] = new ColumnDiff(
             'bar',
             new Column(
                 'baz',
                 Type::getType('string'),
-                ['comment' => 'B comment']
+                ['comment' => 'B comment'],
             ),
-            ['comment']
+            ['comment'],
         );
 
         self::assertEquals($this->getAlterTableColumnCommentsSQL(), $this->platform->getAlterTableSQL($tableDiff));
@@ -505,25 +447,19 @@ abstract class AbstractPlatformTestCase extends TestCase
         self::assertEquals($this->getCreateTableColumnTypeCommentsSQL(), $this->platform->getCreateTableSQL($table));
     }
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     public function getCreateTableColumnCommentsSQL(): array
     {
         self::markTestSkipped('Platform does not support Column comments.');
     }
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     public function getAlterTableColumnCommentsSQL(): array
     {
         self::markTestSkipped('Platform does not support Column comments.');
     }
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     public function getCreateTableColumnTypeCommentsSQL(): array
     {
         self::markTestSkipped('Platform does not support Column comments.');
@@ -547,7 +483,7 @@ abstract class AbstractPlatformTestCase extends TestCase
                 $this->platform->getDefaultValueDeclarationSQL([
                     'type'    => Type::getType($type),
                     'default' => $this->platform->getCurrentTimestampSQL(),
-                ])
+                ]),
             );
         }
     }
@@ -560,7 +496,7 @@ abstract class AbstractPlatformTestCase extends TestCase
                 $this->platform->getDefaultValueDeclarationSQL([
                     'type'    => Type::getType($type),
                     'default' => 1,
-                ])
+                ]),
             );
         }
     }
@@ -574,7 +510,7 @@ abstract class AbstractPlatformTestCase extends TestCase
                 $this->platform->getDefaultValueDeclarationSQL([
                     'type'    => Type::getType($type),
                     'default' => $currentDateSql,
-                ])
+                ]),
             );
         }
     }
@@ -597,24 +533,16 @@ abstract class AbstractPlatformTestCase extends TestCase
         self::assertEquals($this->getQuotedColumnInPrimaryKeySQL(), $sql);
     }
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     abstract protected function getQuotedColumnInPrimaryKeySQL(): array;
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     abstract protected function getQuotedColumnInIndexSQL(): array;
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     abstract protected function getQuotedNameInIndexSQL(): array;
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     abstract protected function getQuotedColumnInForeignKeySQL(): array;
 
     public function testQuotedColumnInIndexPropagation(): void
@@ -661,7 +589,7 @@ abstract class AbstractPlatformTestCase extends TestCase
             ['create', 'foo', '`bar`'],
             ['create', 'bar', '`foo-bar`'],
             [],
-            'FK_WITH_RESERVED_KEYWORD'
+            'FK_WITH_RESERVED_KEYWORD',
         );
 
         // Foreign table with non-reserved keyword as name (does not need quotation).
@@ -681,7 +609,7 @@ abstract class AbstractPlatformTestCase extends TestCase
             ['create', 'foo', '`bar`'],
             ['create', 'bar', '`foo-bar`'],
             [],
-            'FK_WITH_NON_RESERVED_KEYWORD'
+            'FK_WITH_NON_RESERVED_KEYWORD',
         );
 
         // Foreign table with special character in name (needs quotation on some platforms, e.g. Sqlite).
@@ -701,12 +629,12 @@ abstract class AbstractPlatformTestCase extends TestCase
             ['create', 'foo', '`bar`'],
             ['create', 'bar', '`foo-bar`'],
             [],
-            'FK_WITH_INTENDED_QUOTATION'
+            'FK_WITH_INTENDED_QUOTATION',
         );
 
         $sql = $this->platform->getCreateTableSQL(
             $table,
-            AbstractPlatform::CREATE_INDEXES | AbstractPlatform::CREATE_FOREIGNKEYS
+            AbstractPlatform::CREATE_INDEXES | AbstractPlatform::CREATE_FOREIGNKEYS,
         );
         self::assertEquals($this->getQuotedColumnInForeignKeySQL(), $sql);
     }
@@ -717,7 +645,7 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertSame(
             $this->getQuotesReservedKeywordInUniqueConstraintDeclarationSQL(),
-            $this->platform->getUniqueConstraintDeclarationSQL('select', $constraint)
+            $this->platform->getUniqueConstraintDeclarationSQL('select', $constraint),
         );
     }
 
@@ -727,7 +655,7 @@ abstract class AbstractPlatformTestCase extends TestCase
     {
         self::assertSame(
             $this->getQuotesReservedKeywordInTruncateTableSQL(),
-            $this->platform->getTruncateTableSQL('select')
+            $this->platform->getTruncateTableSQL('select'),
         );
     }
 
@@ -743,7 +671,7 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertSame(
             $this->getQuotesReservedKeywordInIndexDeclarationSQL(),
-            $this->platform->getIndexDeclarationSQL('select', $index)
+            $this->platform->getIndexDeclarationSQL('select', $index),
         );
     }
 
@@ -782,14 +710,14 @@ abstract class AbstractPlatformTestCase extends TestCase
             'select',
             new Column(
                 'select',
-                Type::getType('string')
+                Type::getType('string'),
             ),
-            ['type']
+            ['type'],
         );
 
         self::assertStringContainsString(
             $this->platform->quoteIdentifier('select'),
-            implode(';', $this->platform->getAlterTableSQL($tableDiff))
+            implode(';', $this->platform->getAlterTableSQL($tableDiff)),
         );
     }
 
@@ -798,9 +726,7 @@ abstract class AbstractPlatformTestCase extends TestCase
         self::assertFalse($this->platform->usesSequenceEmulatedIdentityColumns());
     }
 
-    /**
-     * @group DBAL-563
-     */
+    /** @group DBAL-563 */
     public function testReturnsIdentitySequenceName(): void
     {
         $this->expectException(Exception::class);
@@ -855,7 +781,7 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertSame(
             $this->platform->getClobTypeDeclarationSQL($column),
-            $this->platform->getJsonTypeDeclarationSQL($column)
+            $this->platform->getJsonTypeDeclarationSQL($column),
         );
     }
 
@@ -871,13 +797,11 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertSame(
             $this->getAlterTableRenameIndexSQL(),
-            $this->platform->getAlterTableSQL($tableDiff)
+            $this->platform->getAlterTableSQL($tableDiff),
         );
     }
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     protected function getAlterTableRenameIndexSQL(): array
     {
         return [
@@ -899,13 +823,11 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertSame(
             $this->getQuotedAlterTableRenameIndexSQL(),
-            $this->platform->getAlterTableSQL($tableDiff)
+            $this->platform->getAlterTableSQL($tableDiff),
         );
     }
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     protected function getQuotedAlterTableRenameIndexSQL(): array
     {
         return [
@@ -966,7 +888,7 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertEquals(
             $this->getQuotedAlterTableRenameColumnSQL(),
-            $this->platform->getAlterTableSQL($diff)
+            $this->platform->getAlterTableSQL($diff),
         );
     }
 
@@ -1004,7 +926,7 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertEquals(
             $this->getQuotedAlterTableChangeColumnLengthSQL(),
-            $this->platform->getAlterTableSQL($diff)
+            $this->platform->getAlterTableSQL($diff),
         );
     }
 
@@ -1027,13 +949,11 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertSame(
             $this->getAlterTableRenameIndexInSchemaSQL(),
-            $this->platform->getAlterTableSQL($tableDiff)
+            $this->platform->getAlterTableSQL($tableDiff),
         );
     }
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     protected function getAlterTableRenameIndexInSchemaSQL(): array
     {
         return [
@@ -1055,13 +975,11 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertSame(
             $this->getQuotedAlterTableRenameIndexInSchemaSQL(),
-            $this->platform->getAlterTableSQL($tableDiff)
+            $this->platform->getAlterTableSQL($tableDiff),
         );
     }
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     protected function getQuotedAlterTableRenameIndexInSchemaSQL(): array
     {
         return [
@@ -1125,7 +1043,7 @@ abstract class AbstractPlatformTestCase extends TestCase
     {
         self::assertEquals(
             $this->getQuotedCommentOnColumnSQLWithoutQuoteCharacter(),
-            $this->platform->getCommentOnColumnSQL('mytable', 'id', 'This is a comment')
+            $this->platform->getCommentOnColumnSQL('mytable', 'id', 'This is a comment'),
         );
     }
 
@@ -1140,7 +1058,7 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertEquals(
             $this->getQuotedCommentOnColumnSQLWithQuoteCharacter(),
-            $this->platform->getCommentOnColumnSQL('mytable', 'id', 'It' . $c . 's a quote !')
+            $this->platform->getCommentOnColumnSQL('mytable', 'id', 'It' . $c . 's a quote !'),
         );
     }
 
@@ -1159,13 +1077,11 @@ abstract class AbstractPlatformTestCase extends TestCase
                 $this->platform->getCommentOnColumnSQL('foo', 'bar', 'comment'), // regular identifiers
                 $this->platform->getCommentOnColumnSQL('`Foo`', '`BAR`', 'comment'), // explicitly quoted identifiers
                 $this->platform->getCommentOnColumnSQL('select', 'from', 'comment'), // reserved keyword identifiers
-            ]
+            ],
         );
     }
 
-    /**
-     * @dataProvider getGeneratesInlineColumnCommentSQL
-     */
+    /** @dataProvider getGeneratesInlineColumnCommentSQL */
     public function testGeneratesInlineColumnCommentSQL(string $comment, string $expectedSql): void
     {
         if (! $this->platform->supportsInlineColumnComments()) {
@@ -1175,9 +1091,7 @@ abstract class AbstractPlatformTestCase extends TestCase
         self::assertSame($expectedSql, $this->platform->getInlineColumnCommentSQL($comment));
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function getGeneratesInlineColumnCommentSQL(): iterable
     {
         return [
@@ -1185,7 +1099,7 @@ abstract class AbstractPlatformTestCase extends TestCase
             'comment requiring escaping' => [
                 sprintf(
                     'Using inline comment delimiter %s works',
-                    static::getInlineColumnCommentDelimiter()
+                    static::getInlineColumnCommentDelimiter(),
                 ),
                 static::getInlineColumnCommentRequiringEscapingSQL(),
             ],
@@ -1236,7 +1150,7 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         $this->expectException(Exception::class);
         $this->expectExceptionMessage(
-            "Operation '" . AbstractPlatform::class . "::getInlineColumnCommentSQL' is not supported by platform."
+            "Operation '" . AbstractPlatform::class . "::getInlineColumnCommentSQL' is not supported by platform.",
         );
         $this->expectExceptionCode(0);
 
@@ -1249,15 +1163,15 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertEquals(
             $this->getQuotedStringLiteralWithoutQuoteCharacter(),
-            $this->platform->quoteStringLiteral('No quote')
+            $this->platform->quoteStringLiteral('No quote'),
         );
         self::assertEquals(
             $this->getQuotedStringLiteralWithQuoteCharacter(),
-            $this->platform->quoteStringLiteral('It' . $c . 's a quote')
+            $this->platform->quoteStringLiteral('It' . $c . 's a quote'),
         );
         self::assertEquals(
             $this->getQuotedStringLiteralQuoteCharacter(),
-            $this->platform->quoteStringLiteral($c)
+            $this->platform->quoteStringLiteral($c),
         );
     }
 
@@ -1274,7 +1188,7 @@ abstract class AbstractPlatformTestCase extends TestCase
         $table->addColumn(
             'bar',
             'integer',
-            ['notnull' => true, 'default' => 666, 'comment' => 'rename test']
+            ['notnull' => true, 'default' => 666, 'comment' => 'rename test'],
         );
 
         $tableDiff                        = new TableDiff('foo');
@@ -1282,56 +1196,15 @@ abstract class AbstractPlatformTestCase extends TestCase
         $tableDiff->renamedColumns['bar'] = new Column(
             'baz',
             Type::getType('integer'),
-            ['notnull' => true, 'default' => 666, 'comment' => 'rename test']
+            ['notnull' => true, 'default' => 666, 'comment' => 'rename test'],
         );
 
         self::assertSame($this->getAlterTableRenameColumnSQL(), $this->platform->getAlterTableSQL($tableDiff));
     }
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     abstract public function getAlterTableRenameColumnSQL(): array;
 
-    public function testQuotesTableIdentifiersInAlterTableSQL(): void
-    {
-        $table = new Table('"foo"');
-        $table->addColumn('id', 'integer');
-        $table->addColumn('fk', 'integer');
-        $table->addColumn('fk2', 'integer');
-        $table->addColumn('fk3', 'integer');
-        $table->addColumn('bar', 'integer');
-        $table->addColumn('baz', 'integer');
-        $table->addForeignKeyConstraint('fk_table', ['fk'], ['id'], [], 'fk1');
-        $table->addForeignKeyConstraint('fk_table', ['fk2'], ['id'], [], 'fk2');
-
-        $tableDiff                        = new TableDiff('"foo"');
-        $tableDiff->fromTable             = $table;
-        $tableDiff->newName               = 'table';
-        $tableDiff->addedColumns['bloo']  = new Column('bloo', Type::getType('integer'));
-        $tableDiff->changedColumns['bar'] = new ColumnDiff(
-            'bar',
-            new Column('bar', Type::getType('integer'), ['notnull' => false]),
-            ['notnull'],
-            $table->getColumn('bar')
-        );
-        $tableDiff->renamedColumns['id']  = new Column('war', Type::getType('integer'));
-        $tableDiff->removedColumns['baz'] = new Column('baz', Type::getType('integer'));
-        $tableDiff->addedForeignKeys[]    = new ForeignKeyConstraint(['fk3'], 'fk_table', ['id'], 'fk_add');
-        $tableDiff->changedForeignKeys[]  = new ForeignKeyConstraint(['fk2'], 'fk_table2', ['id'], 'fk2');
-        $tableDiff->removedForeignKeys[]  = new ForeignKeyConstraint(['fk'], 'fk_table', ['id'], 'fk1');
-
-        self::assertSame(
-            $this->getQuotesTableIdentifiersInAlterTableSQL(),
-            $this->platform->getAlterTableSQL($tableDiff)
-        );
-    }
-
-    /**
-     * @return string[]
-     */
-    abstract protected function getQuotesTableIdentifiersInAlterTableSQL(): array;
-
     public function testAlterStringToFixedString(): void
     {
         $table = new Table('mytable');
@@ -1345,9 +1218,9 @@ abstract class AbstractPlatformTestCase extends TestCase
             new Column(
                 'name',
                 Type::getType('string'),
-                ['fixed' => true, 'length' => 2]
+                ['fixed' => true, 'length' => 2],
             ),
-            ['fixed']
+            ['fixed'],
         );
 
         $sql = $this->platform->getAlterTableSQL($tableDiff);
@@ -1357,9 +1230,7 @@ abstract class AbstractPlatformTestCase extends TestCase
         self::assertEquals($expectedSql, $sql);
     }
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     abstract protected function getAlterStringToFixedStringSQL(): array;
 
     public function testGeneratesAlterTableRenameIndexUsedByForeignKeySQL(): void
@@ -1383,13 +1254,11 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertSame(
             $this->getGeneratesAlterTableRenameIndexUsedByForeignKeySQL(),
-            $this->platform->getAlterTableSQL($tableDiff)
+            $this->platform->getAlterTableSQL($tableDiff),
         );
     }
 
-    /**
-     * @return string[]
-     */
+    /** @return string[] */
     abstract protected function getGeneratesAlterTableRenameIndexUsedByForeignKeySQL(): array;
 
     /**
@@ -1402,9 +1271,7 @@ abstract class AbstractPlatformTestCase extends TestCase
         self::assertSame($expectedSql, $this->platform->getDecimalTypeDeclarationSQL($column));
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function getGeneratesDecimalTypeDeclarationSQL(): iterable
     {
         return [
@@ -1427,9 +1294,7 @@ abstract class AbstractPlatformTestCase extends TestCase
         self::assertSame($expectedSql, $this->platform->getFloatDeclarationSQL($column));
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function getGeneratesFloatDeclarationSQL(): iterable
     {
         return [
@@ -1446,7 +1311,7 @@ abstract class AbstractPlatformTestCase extends TestCase
     {
         self::assertSame(
             '\_25\% off\_ your next purchase \\\\o/',
-            $this->platform->escapeStringForLike('_25% off_ your next purchase \o/', '\\')
+            $this->platform->escapeStringForLike('_25% off_ your next purchase \o/', '\\'),
         );
     }
 
@@ -1456,7 +1321,7 @@ abstract class AbstractPlatformTestCase extends TestCase
 
         self::assertSame(
             $query,
-            $this->platform->modifyLimitQuery($query, null, 0)
+            $this->platform->modifyLimitQuery($query, null, 0),
         );
     }
 
@@ -1464,7 +1329,7 @@ abstract class AbstractPlatformTestCase extends TestCase
     {
         self::assertSame(
             $this->getLimitOffsetCastToIntExpectedQuery(),
-            $this->platform->modifyLimitQuery('SELECT * FROM user', '1 BANANA', '2 APPLES')
+            $this->platform->modifyLimitQuery('SELECT * FROM user', '1 BANANA', '2 APPLES'),
         );
     }
 
@@ -1484,9 +1349,7 @@ abstract class AbstractPlatformTestCase extends TestCase
         self::assertEquals($expectedSql, $declarationSql);
     }
 
-    /**
-     * @return array<int, array{string, array<string, mixed>}>
-     */
+    /** @return array<int, array{string, array<string, mixed>}> */
     public function asciiStringSqlDeclarationDataProvider(): array
     {
         return [
@@ -1520,6 +1383,22 @@ abstract class AbstractPlatformTestCase extends TestCase
         self::assertTrue($this->platform->isCommentedDoctrineType($type));
     }
 
+    public function testEmptyTableDiff(): void
+    {
+        $diff = new TableDiff('test');
+
+        self::assertTrue($diff->isEmpty());
+        self::assertSame([], $this->platform->getAlterTableSQL($diff));
+    }
+
+    public function testEmptySchemaDiff(): void
+    {
+        $diff = new SchemaDiff();
+
+        self::assertTrue($diff->isEmpty());
+        self::assertSame([], $this->platform->getAlterSchemaSQL($diff));
+    }
+
     public function tearDown(): void
     {
         if (! isset($this->backedUpType)) {
