@@ -18,9 +18,7 @@ use UnexpectedValueException;
 
 use function sprintf;
 
-/**
- * @extends AbstractPlatformTestCase<PostgreSQLPlatform>
- */
+/** @extends AbstractPlatformTestCase<PostgreSQLPlatform> */
 class PostgreSQLPlatformTest extends AbstractPlatformTestCase
 {
     public function createPlatform(): AbstractPlatform
@@ -44,24 +42,6 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public function getGenerateAlterTableSql(): array
-    {
-        return [
-            'ALTER TABLE mytable ADD quota INT DEFAULT NULL',
-            'ALTER TABLE mytable DROP foo',
-            'ALTER TABLE mytable ALTER bar TYPE VARCHAR(255)',
-            "ALTER TABLE mytable ALTER bar SET DEFAULT 'def'",
-            'ALTER TABLE mytable ALTER bar SET NOT NULL',
-            'ALTER TABLE mytable ALTER bloo TYPE BOOLEAN',
-            'ALTER TABLE mytable ALTER bloo SET DEFAULT false',
-            'ALTER TABLE mytable ALTER bloo SET NOT NULL',
-            'ALTER TABLE mytable RENAME TO userlist',
-        ];
-    }
-
     public function getGenerateIndexSql(): string
     {
         return 'CREATE INDEX my_idx ON mytable (user_name, last_login)';
@@ -80,12 +60,12 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
             'my_table',
             ['id'],
             'my_fk',
-            ['onDelete' => 'CASCADE']
+            ['onDelete' => 'CASCADE'],
         );
         self::assertEquals(
             'CONSTRAINT my_fk FOREIGN KEY (foreign_id)'
                 . ' REFERENCES my_table (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE',
-            $this->platform->getForeignKeyDeclarationSQL($foreignKey)
+            $this->platform->getForeignKeyDeclarationSQL($foreignKey),
         );
 
         $foreignKey = new ForeignKeyConstraint(
@@ -93,12 +73,12 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
             'my_table',
             ['id'],
             'my_fk',
-            ['match' => 'full']
+            ['match' => 'full'],
         );
         self::assertEquals(
             'CONSTRAINT my_fk FOREIGN KEY (foreign_id)'
                 . ' REFERENCES my_table (id) MATCH full NOT DEFERRABLE INITIALLY IMMEDIATE',
-            $this->platform->getForeignKeyDeclarationSQL($foreignKey)
+            $this->platform->getForeignKeyDeclarationSQL($foreignKey),
         );
 
         $foreignKey = new ForeignKeyConstraint(
@@ -106,12 +86,12 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
             'my_table',
             ['id'],
             'my_fk',
-            ['deferrable' => true]
+            ['deferrable' => true],
         );
         self::assertEquals(
             'CONSTRAINT my_fk FOREIGN KEY (foreign_id)'
                 . ' REFERENCES my_table (id) DEFERRABLE INITIALLY IMMEDIATE',
-            $this->platform->getForeignKeyDeclarationSQL($foreignKey)
+            $this->platform->getForeignKeyDeclarationSQL($foreignKey),
         );
 
         $foreignKey = new ForeignKeyConstraint(
@@ -119,12 +99,12 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
             'my_table',
             ['id'],
             'my_fk',
-            ['deferred' => true]
+            ['deferred' => true],
         );
         self::assertEquals(
             'CONSTRAINT my_fk FOREIGN KEY (foreign_id)'
                 . ' REFERENCES my_table (id) NOT DEFERRABLE INITIALLY DEFERRED',
-            $this->platform->getForeignKeyDeclarationSQL($foreignKey)
+            $this->platform->getForeignKeyDeclarationSQL($foreignKey),
         );
 
         $foreignKey = new ForeignKeyConstraint(
@@ -132,12 +112,12 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
             'my_table',
             ['id'],
             'my_fk',
-            ['feferred' => true]
+            ['feferred' => true],
         );
         self::assertEquals(
             'CONSTRAINT my_fk FOREIGN KEY (foreign_id)'
                 . ' REFERENCES my_table (id) NOT DEFERRABLE INITIALLY DEFERRED',
-            $this->platform->getForeignKeyDeclarationSQL($foreignKey)
+            $this->platform->getForeignKeyDeclarationSQL($foreignKey),
         );
 
         $foreignKey = new ForeignKeyConstraint(
@@ -145,12 +125,12 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
             'my_table',
             ['id'],
             'my_fk',
-            ['deferrable' => true, 'deferred' => true, 'match' => 'full']
+            ['deferrable' => true, 'deferred' => true, 'match' => 'full'],
         );
         self::assertEquals(
             'CONSTRAINT my_fk FOREIGN KEY (foreign_id)'
                 . ' REFERENCES my_table (id) MATCH full DEFERRABLE INITIALLY DEFERRED',
-            $this->platform->getForeignKeyDeclarationSQL($foreignKey)
+            $this->platform->getForeignKeyDeclarationSQL($foreignKey),
         );
     }
 
@@ -161,7 +141,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
 
         self::assertEquals(
             'column1 || column2 || column3',
-            $this->platform->getConcatExpression('column1', 'column2', 'column3')
+            $this->platform->getConcatExpression('column1', 'column2', 'column3'),
         );
 
         self::assertEquals('SUBSTRING(column FROM 5)', $this->platform->getSubstringExpression('column', 5));
@@ -172,19 +152,19 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'SET SESSION CHARACTERISTICS AS TRANSACTION ISOLATION LEVEL READ UNCOMMITTED',
-            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::READ_UNCOMMITTED)
+            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::READ_UNCOMMITTED),
         );
         self::assertEquals(
             'SET SESSION CHARACTERISTICS AS TRANSACTION ISOLATION LEVEL READ COMMITTED',
-            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::READ_COMMITTED)
+            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::READ_COMMITTED),
         );
         self::assertEquals(
             'SET SESSION CHARACTERISTICS AS TRANSACTION ISOLATION LEVEL REPEATABLE READ',
-            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::REPEATABLE_READ)
+            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::REPEATABLE_READ),
         );
         self::assertEquals(
             'SET SESSION CHARACTERISTICS AS TRANSACTION ISOLATION LEVEL SERIALIZABLE',
-            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::SERIALIZABLE)
+            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::SERIALIZABLE),
         );
     }
 
@@ -203,13 +183,11 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
 
         self::assertEquals(
             ['CREATE TABLE autoinc_table (id SERIAL NOT NULL)'],
-            $this->platform->getCreateTableSQL($table)
+            $this->platform->getCreateTableSQL($table),
         );
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function serialTypes(): iterable
     {
         return [
@@ -218,9 +196,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    /**
-     * @dataProvider serialTypes
-     */
+    /** @dataProvider serialTypes */
     public function testGenerateTableWithAutoincrementDoesNotSetDefault(string $type, string $definition): void
     {
         $table  = new Table('autoinc_table_notnull');
@@ -233,9 +209,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
         self::assertEquals([sprintf('CREATE TABLE autoinc_table_notnull (id %s)', $definition)], $sql);
     }
 
-    /**
-     * @dataProvider serialTypes
-     */
+    /** @dataProvider serialTypes */
     public function testCreateTableWithAutoincrementAndNotNullAddsConstraint(string $type, string $definition): void
     {
         $table  = new Table('autoinc_table_notnull_enabled');
@@ -248,9 +222,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
         self::assertEquals([sprintf('CREATE TABLE autoinc_table_notnull_enabled (id %s NOT NULL)', $definition)], $sql);
     }
 
-    /**
-     * @dataProvider serialTypes
-     */
+    /** @dataProvider serialTypes */
     public function testGetDefaultValueDeclarationSQLIgnoresTheDefaultKeyWhenTheFieldIsSerial(string $type): void
     {
         $sql = $this->platform->getDefaultValueDeclarationSQL(
@@ -258,7 +230,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
                 'autoincrement' => true,
                 'type'          => Type::getType($type),
                 'default'       => 1,
-            ]
+            ],
         );
 
         self::assertSame('', $sql);
@@ -268,17 +240,17 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'INT',
-            $this->platform->getIntegerTypeDeclarationSQL([])
+            $this->platform->getIntegerTypeDeclarationSQL([]),
         );
         self::assertEquals(
             'SERIAL',
-            $this->platform->getIntegerTypeDeclarationSQL(['autoincrement' => true])
+            $this->platform->getIntegerTypeDeclarationSQL(['autoincrement' => true]),
         );
         self::assertEquals(
             'SERIAL',
             $this->platform->getIntegerTypeDeclarationSQL(
-                ['autoincrement' => true, 'primary' => true]
-            )
+                ['autoincrement' => true, 'primary' => true],
+            ),
         );
     }
 
@@ -287,16 +259,16 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
         self::assertEquals(
             'CHAR(10)',
             $this->platform->getStringTypeDeclarationSQL(
-                ['length' => 10, 'fixed' => true]
-            )
+                ['length' => 10, 'fixed' => true],
+            ),
         );
         self::assertEquals(
             'VARCHAR(50)',
-            $this->platform->getStringTypeDeclarationSQL(['length' => 50])
+            $this->platform->getStringTypeDeclarationSQL(['length' => 50]),
         );
         self::assertEquals(
             'VARCHAR(255)',
-            $this->platform->getStringTypeDeclarationSQL([])
+            $this->platform->getStringTypeDeclarationSQL([]),
         );
     }
 
@@ -310,15 +282,15 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
         $sequence = new Sequence('myseq', 20, 1);
         self::assertEquals(
             'CREATE SEQUENCE myseq INCREMENT BY 20 MINVALUE 1 START 1',
-            $this->platform->getCreateSequenceSQL($sequence)
+            $this->platform->getCreateSequenceSQL($sequence),
         );
         self::assertEquals(
             'DROP SEQUENCE myseq CASCADE',
-            $this->platform->getDropSequenceSQL('myseq')
+            $this->platform->getDropSequenceSQL('myseq'),
         );
         self::assertEquals(
             "SELECT NEXTVAL('myseq')",
-            $this->platform->getSequenceNextValSQL('myseq')
+            $this->platform->getSequenceNextValSQL('myseq'),
         );
     }
 
@@ -542,36 +514,36 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
             new Column(
                 'dloo1',
                 Type::getType('decimal'),
-                ['precision' => 16, 'scale' => 6]
+                ['precision' => 16, 'scale' => 6],
             ),
-            ['precision']
+            ['precision'],
         );
         $tableDiff->changedColumns['dloo2'] = new ColumnDiff(
             'dloo2',
             new Column(
                 'dloo2',
                 Type::getType('decimal'),
-                ['precision' => 10, 'scale' => 4]
+                ['precision' => 10, 'scale' => 4],
             ),
-            ['scale']
+            ['scale'],
         );
         $tableDiff->changedColumns['dloo3'] = new ColumnDiff(
             'dloo3',
             new Column(
                 'dloo3',
                 Type::getType('decimal'),
-                ['precision' => 10, 'scale' => 6]
+                ['precision' => 10, 'scale' => 6],
             ),
-            []
+            [],
         );
         $tableDiff->changedColumns['dloo4'] = new ColumnDiff(
             'dloo4',
             new Column(
                 'dloo4',
                 Type::getType('decimal'),
-                ['precision' => 16, 'scale' => 8]
+                ['precision' => 16, 'scale' => 8],
             ),
-            ['precision', 'scale']
+            ['precision', 'scale'],
         );
 
         $sql = $this->platform->getAlterTableSQL($tableDiff);
@@ -619,18 +591,14 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
         self::assertSame('mytable_mycolumn_seq', $this->platform->getIdentitySequenceName('mytable', 'mycolumn'));
     }
 
-    /**
-     * @dataProvider dataCreateSequenceWithCache
-     */
+    /** @dataProvider dataCreateSequenceWithCache */
     public function testCreateSequenceWithCache(int $cacheSize, string $expectedSql): void
     {
         $sequence = new Sequence('foo', 1, 1, $cacheSize);
         self::assertStringContainsString($expectedSql, $this->platform->getCreateSequenceSQL($sequence));
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function dataCreateSequenceWithCache(): iterable
     {
         return [
@@ -814,7 +782,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'COMMENT ON COLUMN mytable.id IS NULL',
-            $this->platform->getCommentOnColumnSQL('mytable', 'id', null)
+            $this->platform->getCommentOnColumnSQL('mytable', 'id', null),
         );
     }
 
@@ -831,26 +799,6 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
         return ['ALTER TABLE foo RENAME COLUMN bar TO baz'];
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function getQuotesTableIdentifiersInAlterTableSQL(): array
-    {
-        return [
-            'ALTER TABLE "foo" DROP CONSTRAINT fk1',
-            'ALTER TABLE "foo" DROP CONSTRAINT fk2',
-            'ALTER TABLE "foo" ADD bloo INT NOT NULL',
-            'ALTER TABLE "foo" DROP baz',
-            'ALTER TABLE "foo" ALTER bar DROP NOT NULL',
-            'ALTER TABLE "foo" RENAME COLUMN id TO war',
-            'ALTER TABLE "foo" RENAME TO "table"',
-            'ALTER TABLE "table" ADD CONSTRAINT fk_add FOREIGN KEY (fk3) REFERENCES fk_table (id) NOT DEFERRABLE ' .
-            'INITIALLY IMMEDIATE',
-            'ALTER TABLE "table" ADD CONSTRAINT fk2 FOREIGN KEY (fk2) REFERENCES fk_table2 (id) NOT DEFERRABLE ' .
-            'INITIALLY IMMEDIATE',
-        ];
-    }
-
     /**
      * {@inheritdoc}
      */
@@ -875,7 +823,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
         self::assertInstanceOf(TableDiff::class, $tableDiff);
         self::assertSame(
             ['COMMENT ON COLUMN "foo"."bar" IS \'baz\''],
-            $this->platform->getAlterTableSQL($tableDiff)
+            $this->platform->getAlterTableSQL($tableDiff),
         );
     }
 
@@ -894,7 +842,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
                 'ALTER TABLE "foo" ALTER "bar" TYPE TIMESTAMP(0) WITHOUT TIME ZONE',
                 'COMMENT ON COLUMN "foo"."bar" IS \'(DC2Type:datetime_immutable)\'',
             ],
-            $this->platform->getAlterTableSQL($tableDiff)
+            $this->platform->getAlterTableSQL($tableDiff),
         );
     }
 
@@ -939,7 +887,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableForeignKeysSQL("Foo'Bar\\")
+            $this->platform->getListTableForeignKeysSQL("Foo'Bar\\"),
         );
     }
 
@@ -947,7 +895,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableForeignKeysSQL("Foo'Bar\\.baz_table")
+            $this->platform->getListTableForeignKeysSQL("Foo'Bar\\.baz_table"),
         );
     }
 
@@ -955,7 +903,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableConstraintsSQL("Foo'Bar\\")
+            $this->platform->getListTableConstraintsSQL("Foo'Bar\\"),
         );
     }
 
@@ -963,7 +911,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableIndexesSQL("Foo'Bar\\")
+            $this->platform->getListTableIndexesSQL("Foo'Bar\\"),
         );
     }
 
@@ -971,7 +919,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableIndexesSQL("Foo'Bar\\.baz_table")
+            $this->platform->getListTableIndexesSQL("Foo'Bar\\.baz_table"),
         );
     }
 
@@ -979,7 +927,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableColumnsSQL("Foo'Bar\\")
+            $this->platform->getListTableColumnsSQL("Foo'Bar\\"),
         );
     }
 
@@ -987,7 +935,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableColumnsSQL("Foo'Bar\\.baz_table")
+            $this->platform->getListTableColumnsSQL("Foo'Bar\\.baz_table"),
         );
     }
 
@@ -1007,7 +955,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
                 'ALTER TABLE foo ADD CONSTRAINT test_unique_constraint UNIQUE (id)',
             ],
             $this->platform->getCreateTableSQL($table),
-            'Unique constraints are added to table.'
+            'Unique constraints are added to table.',
         );
     }
 
@@ -1022,7 +970,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
                 "COMMENT ON TABLE foo IS 'foo'",
             ],
             $this->platform->getCreateTableSQL($table),
-            'Comments are added to table.'
+            'Comments are added to table.',
         );
     }
 
@@ -1030,7 +978,7 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'COLLATE "en_US.UTF-8"',
-            $this->platform->getColumnCollationDeclarationSQL('en_US.UTF-8')
+            $this->platform->getColumnCollationDeclarationSQL('en_US.UTF-8'),
         );
     }
 
@@ -1050,17 +998,17 @@ class PostgreSQLPlatformTest extends AbstractPlatformTestCase
     {
         self::assertSame(
             'SMALLSERIAL',
-            $this->platform->getSmallIntTypeDeclarationSQL(['autoincrement' => true])
+            $this->platform->getSmallIntTypeDeclarationSQL(['autoincrement' => true]),
         );
 
         self::assertSame(
             'SMALLINT',
-            $this->platform->getSmallIntTypeDeclarationSQL(['autoincrement' => false])
+            $this->platform->getSmallIntTypeDeclarationSQL(['autoincrement' => false]),
         );
 
         self::assertSame(
             'SMALLINT',
-            $this->platform->getSmallIntTypeDeclarationSQL([])
+            $this->platform->getSmallIntTypeDeclarationSQL([]),
         );
     }
 
