@@ -11,9 +11,7 @@ use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\TransactionIsolationLevel;
 use Doctrine\DBAL\Types\Type;
 
-/**
- * @extends AbstractPlatformTestCase<SqlitePlatform>
- */
+/** @extends AbstractPlatformTestCase<SqlitePlatform> */
 class SqlitePlatformTest extends AbstractPlatformTestCase
 {
     public function createPlatform(): AbstractPlatform
@@ -48,19 +46,19 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'PRAGMA read_uncommitted = 0',
-            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::READ_UNCOMMITTED)
+            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::READ_UNCOMMITTED),
         );
         self::assertEquals(
             'PRAGMA read_uncommitted = 1',
-            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::READ_COMMITTED)
+            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::READ_COMMITTED),
         );
         self::assertEquals(
             'PRAGMA read_uncommitted = 1',
-            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::REPEATABLE_READ)
+            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::REPEATABLE_READ),
         );
         self::assertEquals(
             'PRAGMA read_uncommitted = 1',
-            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::SERIALIZABLE)
+            $this->platform->getSetTransactionIsolationSQL(TransactionIsolationLevel::SERIALIZABLE),
         );
     }
 
@@ -73,7 +71,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::assertSame(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
-            $this->platform->getIntegerTypeDeclarationSQL(['autoincrement' => true, 'unsigned' => true])
+            $this->platform->getIntegerTypeDeclarationSQL(['autoincrement' => true, 'unsigned' => true]),
         );
     }
 
@@ -81,25 +79,25 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'TINYINT',
-            $this->platform->getTinyIntTypeDeclarationSQL([])
+            $this->platform->getTinyIntTypeDeclarationSQL([]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
-            $this->platform->getTinyIntTypeDeclarationSQL(['autoincrement' => true])
+            $this->platform->getTinyIntTypeDeclarationSQL(['autoincrement' => true]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
             $this->platform->getTinyIntTypeDeclarationSQL(
-                ['autoincrement' => true, 'primary' => true]
-            )
+                ['autoincrement' => true, 'primary' => true],
+            ),
         );
         self::assertEquals(
             'TINYINT',
-            $this->platform->getTinyIntTypeDeclarationSQL(['unsigned' => false])
+            $this->platform->getTinyIntTypeDeclarationSQL(['unsigned' => false]),
         );
         self::assertEquals(
             'TINYINT UNSIGNED',
-            $this->platform->getTinyIntTypeDeclarationSQL(['unsigned' => true])
+            $this->platform->getTinyIntTypeDeclarationSQL(['unsigned' => true]),
         );
     }
 
@@ -107,29 +105,29 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'SMALLINT',
-            $this->platform->getSmallIntTypeDeclarationSQL([])
+            $this->platform->getSmallIntTypeDeclarationSQL([]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
-            $this->platform->getSmallIntTypeDeclarationSQL(['autoincrement' => true])
+            $this->platform->getSmallIntTypeDeclarationSQL(['autoincrement' => true]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
-            $this->platform->getTinyIntTypeDeclarationSQL(['autoincrement' => true, 'unsigned' => true])
+            $this->platform->getTinyIntTypeDeclarationSQL(['autoincrement' => true, 'unsigned' => true]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
             $this->platform->getSmallIntTypeDeclarationSQL(
-                ['autoincrement' => true, 'primary' => true]
-            )
+                ['autoincrement' => true, 'primary' => true],
+            ),
         );
         self::assertEquals(
             'SMALLINT',
-            $this->platform->getSmallIntTypeDeclarationSQL(['unsigned' => false])
+            $this->platform->getSmallIntTypeDeclarationSQL(['unsigned' => false]),
         );
         self::assertEquals(
             'SMALLINT UNSIGNED',
-            $this->platform->getSmallIntTypeDeclarationSQL(['unsigned' => true])
+            $this->platform->getSmallIntTypeDeclarationSQL(['unsigned' => true]),
         );
     }
 
@@ -137,29 +135,29 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'MEDIUMINT',
-            $this->platform->getMediumIntTypeDeclarationSQL([])
+            $this->platform->getMediumIntTypeDeclarationSQL([]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
-            $this->platform->getMediumIntTypeDeclarationSQL(['autoincrement' => true])
+            $this->platform->getMediumIntTypeDeclarationSQL(['autoincrement' => true]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
-            $this->platform->getMediumIntTypeDeclarationSQL(['autoincrement' => true, 'unsigned' => true])
+            $this->platform->getMediumIntTypeDeclarationSQL(['autoincrement' => true, 'unsigned' => true]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
             $this->platform->getMediumIntTypeDeclarationSQL(
-                ['autoincrement' => true, 'primary' => true]
-            )
+                ['autoincrement' => true, 'primary' => true],
+            ),
         );
         self::assertEquals(
             'MEDIUMINT',
-            $this->platform->getMediumIntTypeDeclarationSQL(['unsigned' => false])
+            $this->platform->getMediumIntTypeDeclarationSQL(['unsigned' => false]),
         );
         self::assertEquals(
             'MEDIUMINT UNSIGNED',
-            $this->platform->getMediumIntTypeDeclarationSQL(['unsigned' => true])
+            $this->platform->getMediumIntTypeDeclarationSQL(['unsigned' => true]),
         );
     }
 
@@ -167,29 +165,29 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'INTEGER',
-            $this->platform->getIntegerTypeDeclarationSQL([])
+            $this->platform->getIntegerTypeDeclarationSQL([]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
-            $this->platform->getIntegerTypeDeclarationSQL(['autoincrement' => true])
+            $this->platform->getIntegerTypeDeclarationSQL(['autoincrement' => true]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
-            $this->platform->getIntegerTypeDeclarationSQL(['autoincrement' => true, 'unsigned' => true])
+            $this->platform->getIntegerTypeDeclarationSQL(['autoincrement' => true, 'unsigned' => true]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
             $this->platform->getIntegerTypeDeclarationSQL(
-                ['autoincrement' => true, 'primary' => true]
-            )
+                ['autoincrement' => true, 'primary' => true],
+            ),
         );
         self::assertEquals(
             'INTEGER',
-            $this->platform->getIntegerTypeDeclarationSQL(['unsigned' => false])
+            $this->platform->getIntegerTypeDeclarationSQL(['unsigned' => false]),
         );
         self::assertEquals(
             'INTEGER UNSIGNED',
-            $this->platform->getIntegerTypeDeclarationSQL(['unsigned' => true])
+            $this->platform->getIntegerTypeDeclarationSQL(['unsigned' => true]),
         );
     }
 
@@ -197,29 +195,29 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'BIGINT',
-            $this->platform->getBigIntTypeDeclarationSQL([])
+            $this->platform->getBigIntTypeDeclarationSQL([]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
-            $this->platform->getBigIntTypeDeclarationSQL(['autoincrement' => true])
+            $this->platform->getBigIntTypeDeclarationSQL(['autoincrement' => true]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
-            $this->platform->getBigIntTypeDeclarationSQL(['autoincrement' => true, 'unsigned' => true])
+            $this->platform->getBigIntTypeDeclarationSQL(['autoincrement' => true, 'unsigned' => true]),
         );
         self::assertEquals(
             'INTEGER PRIMARY KEY AUTOINCREMENT',
             $this->platform->getBigIntTypeDeclarationSQL(
-                ['autoincrement' => true, 'primary' => true]
-            )
+                ['autoincrement' => true, 'primary' => true],
+            ),
         );
         self::assertEquals(
             'BIGINT',
-            $this->platform->getBigIntTypeDeclarationSQL(['unsigned' => false])
+            $this->platform->getBigIntTypeDeclarationSQL(['unsigned' => false]),
         );
         self::assertEquals(
             'BIGINT UNSIGNED',
-            $this->platform->getBigIntTypeDeclarationSQL(['unsigned' => true])
+            $this->platform->getBigIntTypeDeclarationSQL(['unsigned' => true]),
         );
     }
 
@@ -227,17 +225,17 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::assertEquals(
             'CHAR(10)',
-            $this->platform->getVarcharTypeDeclarationSQL(
-                ['length' => 10, 'fixed' => true]
-            )
+            $this->platform->getStringTypeDeclarationSQL(
+                ['length' => 10, 'fixed' => true],
+            ),
         );
         self::assertEquals(
             'VARCHAR(50)',
-            $this->platform->getVarcharTypeDeclarationSQL(['length' => 50])
+            $this->platform->getStringTypeDeclarationSQL(['length' => 50]),
         );
         self::assertEquals(
             'VARCHAR(255)',
-            $this->platform->getVarcharTypeDeclarationSQL([])
+            $this->platform->getStringTypeDeclarationSQL([]),
         );
     }
 
@@ -288,24 +286,6 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         self::assertEquals('SELECT * FROM user LIMIT -1 OFFSET 10', $sql);
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public function getGenerateAlterTableSql(): array
-    {
-        return [
-            'CREATE TEMPORARY TABLE __temp__mytable AS SELECT id, bar, bloo FROM mytable',
-            'DROP TABLE mytable',
-            'CREATE TABLE mytable (id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, '
-                . "baz VARCHAR(255) DEFAULT 'def' NOT NULL, "
-                . 'bloo BOOLEAN DEFAULT 0 NOT NULL, '
-                . 'quota INTEGER DEFAULT NULL)',
-            'INSERT INTO mytable (id, baz, bloo) SELECT id, bar, bloo FROM __temp__mytable',
-            'DROP TABLE __temp__mytable',
-            'ALTER TABLE mytable RENAME TO userlist',
-        ];
-    }
-
     public function testGenerateTableSqlShouldNotAutoQuotePrimaryKey(): void
     {
         $table = new Table('test');
@@ -315,7 +295,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         $createTableSQL = $this->platform->getCreateTableSQL($table);
         self::assertEquals(
             'CREATE TABLE test ("like" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL)',
-            $createTableSQL[0]
+            $createTableSQL[0],
         );
     }
 
@@ -337,9 +317,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         self::assertEquals($expected, $this->platform->getAlterTableSQL($diff));
     }
 
-    /**
-     * @dataProvider complexDiffProvider
-     */
+    /** @dataProvider complexDiffProvider */
     public function testAlterTableAddComplexColumns(TableDiff $diff): void
     {
         $this->expectException(Exception::class);
@@ -360,9 +338,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         $this->platform->getAlterTableSQL($tableDiff);
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function complexDiffProvider(): iterable
     {
         $date                       = new TableDiff('user');
@@ -426,14 +402,10 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         $diff->newName                  = 'client';
         $diff->renamedColumns['id']     = new Column('key', Type::getType('integer'), []);
         $diff->renamedColumns['post']   = new Column('comment', Type::getType('integer'), []);
-        $diff->removedColumns['parent'] = new Column('comment', Type::getType('integer'), []);
+        $diff->removedColumns['parent'] = new Column('parent', Type::getType('integer'), []);
         $diff->removedIndexes['index1'] = $table->getIndex('index1');
 
         $sql = [
-            'DROP INDEX IDX_8D93D64923A0E66',
-            'DROP INDEX IDX_8D93D6495A8A6C8D',
-            'DROP INDEX IDX_8D93D6493D8E604F',
-            'DROP INDEX index1',
             'CREATE TEMPORARY TABLE __temp__user AS SELECT id, article, post FROM user',
             'DROP TABLE user',
             'CREATE TABLE user ('
@@ -498,6 +470,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
             'REFERENCES foo ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE, ' .
             'CONSTRAINT FK_WITH_INTENDED_QUOTATION FOREIGN KEY ("create", foo, "bar") ' .
             'REFERENCES "foo-bar" ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE)',
+            'CREATE INDEX IDX_22660D028FD6E0FB8C736521D79164E3 ON "quoted" ("create", foo, "bar")',
         ];
     }
 
@@ -605,7 +578,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::markTestIncomplete(
             'Test currently produces broken SQL due to SQLLitePlatform::getAlterTable() being broken ' .
-            'when used with schemas.'
+            'when used with schemas.',
         );
     }
 
@@ -613,7 +586,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::markTestIncomplete(
             'Test currently produces broken SQL due to SQLLitePlatform::getAlterTable() being broken ' .
-            'when used with schemas.'
+            'when used with schemas.',
         );
     }
 
@@ -637,28 +610,6 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         ];
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function getQuotesTableIdentifiersInAlterTableSQL(): array
-    {
-        return [
-            'DROP INDEX IDX_8C736521A81E660E',
-            'DROP INDEX IDX_8C736521FDC58D6C',
-            'CREATE TEMPORARY TABLE __temp__foo AS SELECT fk, fk2, id, fk3, bar FROM "foo"',
-            'DROP TABLE "foo"',
-            'CREATE TABLE "foo" (fk2 INTEGER NOT NULL, fk3 INTEGER NOT NULL, fk INTEGER NOT NULL, ' .
-            'war INTEGER NOT NULL, bar INTEGER DEFAULT NULL, bloo INTEGER NOT NULL, ' .
-            'CONSTRAINT fk2 FOREIGN KEY (fk2) REFERENCES fk_table2 (id) NOT DEFERRABLE INITIALLY IMMEDIATE, ' .
-            'CONSTRAINT fk_add FOREIGN KEY (fk3) REFERENCES fk_table (id) NOT DEFERRABLE INITIALLY IMMEDIATE)',
-            'INSERT INTO "foo" (fk, fk2, war, fk3, bar) SELECT fk, fk2, id, fk3, bar FROM __temp__foo',
-            'DROP TABLE __temp__foo',
-            'ALTER TABLE "foo" RENAME TO "table"',
-            'CREATE INDEX IDX_8C736521A81E660E ON "table" (fk)',
-            'CREATE INDEX IDX_8C736521FDC58D6C ON "table" (fk2)',
-        ];
-    }
-
     /**
      * {@inheritdoc}
      */
@@ -726,8 +677,6 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     protected function getGeneratesAlterTableRenameIndexUsedByForeignKeySQL(): array
     {
         return [
-            'DROP INDEX idx_foo',
-            'DROP INDEX idx_bar',
             'CREATE TEMPORARY TABLE __temp__mytable AS SELECT foo, bar, baz FROM mytable',
             'DROP TABLE mytable',
             'CREATE TABLE mytable (foo INTEGER NOT NULL, bar INTEGER NOT NULL, baz INTEGER NOT NULL, '
@@ -746,7 +695,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableConstraintsSQL("Foo'Bar\\")
+            $this->platform->getListTableConstraintsSQL("Foo'Bar\\"),
         );
     }
 
@@ -754,7 +703,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableColumnsSQL("Foo'Bar\\")
+            $this->platform->getListTableColumnsSQL("Foo'Bar\\"),
         );
     }
 
@@ -762,7 +711,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableIndexesSQL("Foo'Bar\\")
+            $this->platform->getListTableIndexesSQL("Foo'Bar\\"),
         );
     }
 
@@ -770,15 +719,20 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::assertStringContainsStringIgnoringCase(
             "'Foo''Bar\\'",
-            $this->platform->getListTableForeignKeysSQL("Foo'Bar\\")
+            $this->platform->getListTableForeignKeysSQL("Foo'Bar\\"),
         );
     }
 
+    public function testQuotesDropForeignKeySQL(): void
+    {
+        $this->markTestSkipped('SQLite does not support altering foreign key constraints.');
+    }
+
     public function testDateAddStaticNumberOfDays(): void
     {
         self::assertSame(
             "DATE(rentalBeginsOn,'+12 DAY')",
-            $this->platform->getDateAddDaysExpression('rentalBeginsOn', 12)
+            $this->platform->getDateAddDaysExpression('rentalBeginsOn', 12),
         );
     }
 
@@ -786,7 +740,7 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
     {
         self::assertSame(
             "DATE(rentalBeginsOn,'+' || duration || ' DAY')",
-            $this->platform->getDateAddDaysExpression('rentalBeginsOn', 'duration')
+            $this->platform->getDateAddDaysExpression('rentalBeginsOn', 'duration'),
         );
     }
 
@@ -795,14 +749,6 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         self::assertTrue($this->platform->supportsColumnCollation());
     }
 
-    public function testColumnCollationDeclarationSQL(): void
-    {
-        self::assertSame(
-            'COLLATE NOCASE',
-            $this->platform->getColumnCollationDeclarationSQL('NOCASE')
-        );
-    }
-
     public function testGetCreateTableSQLWithColumnCollation(): void
     {
         $table = new Table('foo');
@@ -812,9 +758,9 @@ class SqlitePlatformTest extends AbstractPlatformTestCase
         self::assertSame(
             [
                 'CREATE TABLE foo (no_collation VARCHAR(255) NOT NULL, '
-                    . 'column_collation VARCHAR(255) NOT NULL COLLATE NOCASE)',
+                    . 'column_collation VARCHAR(255) NOT NULL COLLATE "NOCASE")',
             ],
-            $this->platform->getCreateTableSQL($table)
+            $this->platform->getCreateTableSQL($table),
         );
     }
 }
