@@ -2,6 +2,7 @@
 
 namespace Doctrine\DBAL\Tests\Query;
 
+use Doctrine\DBAL\ArrayParameterType;
 use Doctrine\DBAL\Cache\QueryCacheProfile;
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\ParameterType;
@@ -181,7 +182,7 @@ class QueryBuilderTest extends TestCase
         self::assertEquals(
             'SELECT u.*, p.* FROM users u'
                 . ' WHERE (((u.username = ?) AND (u.username = ?)) OR (u.name = ?)) AND (u.name = ?)',
-            (string) $qb
+            (string) $qb,
         );
     }
 
@@ -278,7 +279,7 @@ class QueryBuilderTest extends TestCase
 
         self::assertEquals(
             'SELECT u.*, p.* FROM users u GROUP BY u.id HAVING (u.name = ?) AND (u.username = ?)',
-            (string) $qb
+            (string) $qb,
         );
     }
 
@@ -294,7 +295,7 @@ class QueryBuilderTest extends TestCase
 
         self::assertEquals(
             'SELECT u.*, p.* FROM users u GROUP BY u.id HAVING (u.name = ?) OR (u.username = ?)',
-            (string) $qb
+            (string) $qb,
         );
     }
 
@@ -310,7 +311,7 @@ class QueryBuilderTest extends TestCase
 
         self::assertEquals(
             'SELECT u.*, p.* FROM users u GROUP BY u.id HAVING (u.name = ?) OR (u.username = ?)',
-            (string) $qb
+            (string) $qb,
         );
     }
 
@@ -327,7 +328,7 @@ class QueryBuilderTest extends TestCase
 
         self::assertEquals(
             'SELECT u.*, p.* FROM users u GROUP BY u.id HAVING ((u.name = ?) OR (u.username = ?)) AND (u.username = ?)',
-            (string) $qb
+            (string) $qb,
         );
     }
 
@@ -491,7 +492,7 @@ class QueryBuilderTest extends TestCase
                 [
                     'foo' => '?',
                     'bar' => '?',
-                ]
+                ],
             );
 
         self::assertEquals(QueryBuilder::INSERT, $qb->getType());
@@ -506,13 +507,13 @@ class QueryBuilderTest extends TestCase
                 [
                     'foo' => '?',
                     'bar' => '?',
-                ]
+                ],
             )
             ->values(
                 [
                     'bar' => '?',
                     'foo' => '?',
-                ]
+                ],
             );
 
         self::assertEquals(QueryBuilder::INSERT, $qb->getType());
@@ -536,7 +537,7 @@ class QueryBuilderTest extends TestCase
         $qb = new QueryBuilder($this->conn);
         $qb->insert('users')
             ->values(
-                ['foo' => '?']
+                ['foo' => '?'],
             )
             ->setValue('bar', '?');
 
@@ -575,9 +576,7 @@ class QueryBuilderTest extends TestCase
         self::assertEquals($sql1, $qb->getSQL());
     }
 
-    /**
-     * @dataProvider maxResultsProvider
-     */
+    /** @dataProvider maxResultsProvider */
     public function testSetMaxResults(?int $maxResults): void
     {
         $qb = new QueryBuilder($this->conn);
@@ -587,9 +586,7 @@ class QueryBuilderTest extends TestCase
         self::assertEquals($maxResults, $qb->getMaxResults());
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function maxResultsProvider(): iterable
     {
         return [
@@ -634,7 +631,7 @@ class QueryBuilderTest extends TestCase
         $qb = new QueryBuilder($this->conn);
 
         $qb->select('u.*')->from('users', 'u')->where(
-            $qb->expr()->eq('u.name', $qb->createNamedParameter(10, ParameterType::INTEGER))
+            $qb->expr()->eq('u.name', $qb->createNamedParameter(10, ParameterType::INTEGER)),
         );
 
         self::assertEquals('SELECT u.* FROM users u WHERE u.name = :dcValue1', (string) $qb);
@@ -647,7 +644,7 @@ class QueryBuilderTest extends TestCase
         $qb = new QueryBuilder($this->conn);
 
         $qb->select('u.*')->from('users', 'u')->where(
-            $qb->expr()->eq('u.name', $qb->createNamedParameter(10, ParameterType::INTEGER, ':test'))
+            $qb->expr()->eq('u.name', $qb->createNamedParameter(10, ParameterType::INTEGER, ':test')),
         );
 
         self::assertEquals('SELECT u.* FROM users u WHERE u.name = :test', (string) $qb);
@@ -660,7 +657,7 @@ class QueryBuilderTest extends TestCase
         $qb = new QueryBuilder($this->conn);
 
         $qb->select('u.*')->from('users', 'u')->where(
-            $qb->expr()->eq('u.name', $qb->createPositionalParameter(10, ParameterType::INTEGER))
+            $qb->expr()->eq('u.name', $qb->createPositionalParameter(10, ParameterType::INTEGER)),
         );
 
         self::assertEquals('SELECT u.* FROM users u WHERE u.name = ?', (string) $qb);
@@ -682,7 +679,7 @@ class QueryBuilderTest extends TestCase
         $this->expectException(QueryException::class);
         $this->expectExceptionMessage(
             "The given alias 'invalid' is not part of any FROM or JOIN clause table. "
-                . 'The currently registered aliases are: news, nv.'
+                . 'The currently registered aliases are: news, nv.',
         );
         self::assertEquals('', $qb->getSQL());
     }
@@ -704,7 +701,7 @@ class QueryBuilderTest extends TestCase
                 . " INNER JOIN nodeversion nv ON nv.refId = news.id AND nv.refEntityname='Entity\\News'"
                 . ' INNER JOIN nodetranslation nt ON nv.nodetranslation = nt.id'
                 . ' INNER JOIN node n ON nt.node = n.id WHERE (nt.lang = ?) AND (n.deleted = 0)',
-            $qb->getSQL()
+            $qb->getSQL(),
         );
     }
 
@@ -725,7 +722,7 @@ class QueryBuilderTest extends TestCase
             . ' INNER JOIN permissions p ON p.user_id = u.id, articles a'
             . ' INNER JOIN comments c ON c.article_id = a.id'
             . ' WHERE (u.id = a.user_id) AND (p.read = 1)',
-            $qb->getSQL()
+            $qb->getSQL(),
         );
     }
 
@@ -747,7 +744,7 @@ class QueryBuilderTest extends TestCase
             'INNER JOIN table_d d ON a.fk_d = d.id ' .
             'INNER JOIN table_c c ON c.fk_b = b.id AND b.language = ? ' .
             'INNER JOIN table_e e ON e.fk_c = c.id AND e.fk_d = d.id',
-            (string) $qb
+            (string) $qb,
         );
     }
 
@@ -773,7 +770,7 @@ class QueryBuilderTest extends TestCase
             'INNER JOIN table_e e ON e.fk_c = c.id AND e.fk_d = d.id, ' .
             'table_f f ' .
             'INNER JOIN table_g g ON f.fk_g = g.id',
-            (string) $qb
+            (string) $qb,
         );
     }
 
@@ -835,7 +832,7 @@ class QueryBuilderTest extends TestCase
                 . ' INNER JOIN permissions p ON p.user_id = users.id, articles'
                 . ' INNER JOIN comments c ON c.article_id = articles.id'
                 . ' WHERE (users.id = articles.user_id) AND (p.read = 1)',
-            $qb->getSQL()
+            $qb->getSQL(),
         );
     }
 
@@ -853,7 +850,7 @@ class QueryBuilderTest extends TestCase
             'SELECT u.id FROM users u'
                 . ' INNER JOIN permissions p ON p.user_id = u.id, articles'
                 . ' INNER JOIN comments c ON c.article_id = articles.id',
-            $qb->getSQL()
+            $qb->getSQL(),
         );
     }
 
@@ -919,6 +916,29 @@ class QueryBuilderTest extends TestCase
         ], $qb->getParameterTypes());
     }
 
+    public function testArrayParameters(): void
+    {
+        $qb = new QueryBuilder($this->conn);
+
+        $qb->select('*')->from('users');
+
+        self::assertSame([], $qb->getParameterTypes());
+
+        $qb->where('id IN (:ids)');
+        $qb->setParameter('ids', [1, 2, 3], ArrayParameterType::INTEGER);
+
+        $qb->andWhere('name IN (:names)');
+        $qb->setParameter('names', ['john', 'jane'], ArrayParameterType::STRING);
+
+        self::assertSame(ArrayParameterType::INTEGER, $qb->getParameterType('ids'));
+        self::assertSame(ArrayParameterType::STRING, $qb->getParameterType('names'));
+
+        self::assertSame([
+            'ids'   => ArrayParameterType::INTEGER,
+            'names' => ArrayParameterType::STRING,
+        ], $qb->getParameterTypes());
+    }
+
     public function testJoinWithNonUniqueAliasThrowsException(): void
     {
         $qb = new QueryBuilder($this->conn);
@@ -929,7 +949,7 @@ class QueryBuilderTest extends TestCase
 
         $this->expectException(QueryException::class);
         $this->expectExceptionMessage(
-            "The given alias 'a' is not unique in FROM and JOIN clause table. The currently registered aliases are: a."
+            "The given alias 'a' is not unique in FROM and JOIN clause table. The currently registered aliases are: a.",
         );
 
         $qb->getSQL();
@@ -1085,7 +1105,7 @@ class QueryBuilderTest extends TestCase
                 [
                     ['username' => 'jwage', 'password' => 'changeme'],
                     ['username' => 'support', 'password' => 'p@ssword'],
-                ]
+                ],
             );
 
         $results = $qb->select($select)
@@ -1099,7 +1119,7 @@ class QueryBuilderTest extends TestCase
                 ['username' => 'jwage', 'password' => 'changeme'],
                 ['username' => 'support', 'password' => 'p@ssword'],
             ],
-            $results
+            $results,
         );
     }
 
@@ -1131,7 +1151,7 @@ class QueryBuilderTest extends TestCase
                 [
                     ['jwage', 'changeme'],
                     ['support', 'p@ssword'],
-                ]
+                ],
             );
 
         $results = $qb->select($select)
@@ -1145,7 +1165,7 @@ class QueryBuilderTest extends TestCase
                 ['jwage', 'changeme'],
                 ['support', 'p@ssword'],
             ],
-            $results
+            $results,
         );
     }
 
@@ -1177,7 +1197,7 @@ class QueryBuilderTest extends TestCase
                 [
                     'jwage' => 'changeme',
                     'support' => 'p@ssw0rd',
-                ]
+                ],
             );
 
         $results = $qb->select($select)
@@ -1191,7 +1211,7 @@ class QueryBuilderTest extends TestCase
                 'jwage' => 'changeme',
                 'support' => 'p@ssw0rd',
             ],
-            $results
+            $results,
         );
     }
 
@@ -1225,7 +1245,7 @@ class QueryBuilderTest extends TestCase
                         'username' => 'jwage',
                         'password' => 'changeme',
                     ],
-                ]
+                ],
             );
 
         $results = $qb->select($select)
@@ -1241,7 +1261,7 @@ class QueryBuilderTest extends TestCase
                     'password' => 'changeme',
                 ],
             ],
-            $results
+            $results,
         );
     }
 
@@ -1273,7 +1293,7 @@ class QueryBuilderTest extends TestCase
                 [
                     'jwage',
                     'support',
-                ]
+                ],
             );
 
         $results = $qb->select($select)
@@ -1287,7 +1307,7 @@ class QueryBuilderTest extends TestCase
                 'jwage',
                 'support',
             ],
-            $results
+            $results,
         );
     }
 
@@ -1372,7 +1392,7 @@ class QueryBuilderTest extends TestCase
 
         self::assertSame(
             $mockedResult,
-            $results
+            $results,
         );
     }
 
@@ -1408,7 +1428,7 @@ class QueryBuilderTest extends TestCase
 
         self::assertSame(
             $mockedResult,
-            $results
+            $results,
         );
     }
 
@@ -1442,7 +1462,7 @@ class QueryBuilderTest extends TestCase
 
         self::assertSame(
             $mockedResult,
-            $results
+            $results,
         );
     }
 }
