@@ -39,7 +39,7 @@ class ComparatorTest extends TestCase
                 'bugdb',
                 [
                     'integercolumn1' => new Column('integercolumn1', Type::getType('integer')),
-                ]
+                ],
             ),
         ]);
         $schema2 = new Schema([
@@ -47,7 +47,7 @@ class ComparatorTest extends TestCase
                 'bugdb',
                 [
                     'integercolumn1' => new Column('integercolumn1', Type::getType('integer')),
-                ]
+                ],
             ),
         ]);
 
@@ -64,7 +64,7 @@ class ComparatorTest extends TestCase
                 [
                     'integercolumn1' => new Column('integercolumn1', Type::getType('integer')),
                     'integercolumn2' => new Column('integercolumn2', Type::getType('integer')),
-                ]
+                ],
             ),
         ]);
         $schema2 = new Schema([
@@ -73,7 +73,7 @@ class ComparatorTest extends TestCase
                 [
                     'integercolumn2' => new Column('integercolumn2', Type::getType('integer')),
                     'integercolumn1' => new Column('integercolumn1', Type::getType('integer')),
-                ]
+                ],
             ),
         ]);
 
@@ -131,7 +131,7 @@ class ComparatorTest extends TestCase
                 [
                     'integercolumn1' => $missingColumn,
                     'integercolumn2' => new Column('integercolumn2', Type::getType('integer')),
-                ]
+                ],
             ),
         ]);
         $schema2       = new Schema([
@@ -139,7 +139,7 @@ class ComparatorTest extends TestCase
                 'bugdb',
                 [
                     'integercolumn2' => new Column('integercolumn2', Type::getType('integer')),
-                ]
+                ],
             ),
         ]);
 
@@ -150,9 +150,9 @@ class ComparatorTest extends TestCase
                     'bugdb',
                     [],
                     [],
-                    ['integercolumn1' => $missingColumn]
+                    ['integercolumn1' => $missingColumn],
                 ),
-            ]
+            ],
         );
         $expected->fromSchema                        = $schema1;
         $expected->changedTables['bugdb']->fromTable = $schema1->getTable('bugdb');
@@ -167,7 +167,7 @@ class ComparatorTest extends TestCase
                 'bugdb',
                 [
                     'integercolumn1' => new Column('integercolumn1', Type::getType('integer')),
-                ]
+                ],
             ),
         ]);
         $schema2 = new Schema([
@@ -176,7 +176,7 @@ class ComparatorTest extends TestCase
                 [
                     'integercolumn1' => new Column('integercolumn1', Type::getType('integer')),
                     'integercolumn2' => new Column('integercolumn2', Type::getType('integer')),
-                ]
+                ],
             ),
         ]);
 
@@ -187,9 +187,9 @@ class ComparatorTest extends TestCase
                     'bugdb',
                     [
                         'integercolumn2' => new Column('integercolumn2', Type::getType('integer')),
-                    ]
+                    ],
                 ),
-            ]
+            ],
         );
         $expected->fromSchema                        = $schema1;
         $expected->changedTables['bugdb']->fromTable = $schema1->getTable('bugdb');
@@ -282,9 +282,9 @@ class ComparatorTest extends TestCase
                     'primary' => new Index(
                         'primary',
                         ['integercolumn1'],
-                        true
+                        true,
                     ),
-                ]
+                ],
             ),
         ]);
         $schema2 = new Schema([
@@ -293,7 +293,7 @@ class ComparatorTest extends TestCase
                 [
                     'integercolumn1' => new Column('integercolumn1', Type::getType('integer')),
                     'integercolumn2' => new Column('integercolumn2', Type::getType('integer')),
-                ]
+                ],
             ),
         ]);
 
@@ -311,11 +311,11 @@ class ComparatorTest extends TestCase
                         'primary' => new Index(
                             'primary',
                             ['integercolumn1'],
-                            true
+                            true,
                         ),
-                    ]
+                    ],
                 ),
-            ]
+            ],
         );
         $expected->fromSchema                        = $schema1;
         $expected->changedTables['bugdb']->fromTable = $schema1->getTable('bugdb');
@@ -331,7 +331,7 @@ class ComparatorTest extends TestCase
                 [
                     'integercolumn1' => new Column('integercolumn1', Type::getType('integer')),
                     'integercolumn2' => new Column('integercolumn2', Type::getType('integer')),
-                ]
+                ],
             ),
         ]);
         $schema2 = new Schema([
@@ -345,9 +345,9 @@ class ComparatorTest extends TestCase
                     'primary' => new Index(
                         'primary',
                         ['integercolumn1'],
-                        true
+                        true,
                     ),
-                ]
+                ],
             ),
         ]);
 
@@ -363,11 +363,11 @@ class ComparatorTest extends TestCase
                         'primary' => new Index(
                             'primary',
                             ['integercolumn1'],
-                            true
+                            true,
                         ),
-                    ]
+                    ],
                 ),
-            ]
+            ],
         );
         $expected->fromSchema                        = $schema1;
         $expected->changedTables['bugdb']->fromTable = $schema1->getTable('bugdb');
@@ -388,9 +388,9 @@ class ComparatorTest extends TestCase
                     'primary' => new Index(
                         'primary',
                         ['integercolumn1'],
-                        true
+                        true,
                     ),
-                ]
+                ],
             ),
         ]);
         $schema2 = new Schema([
@@ -404,9 +404,9 @@ class ComparatorTest extends TestCase
                     'primary' => new Index(
                         'primary',
                         ['integercolumn1', 'integercolumn2'],
-                        true
+                        true,
                     ),
-                ]
+                ],
             ),
         ]);
 
@@ -426,11 +426,11 @@ class ComparatorTest extends TestCase
                                 'integercolumn1',
                                 'integercolumn2',
                             ],
-                            true
+                            true,
                         ),
-                    ]
+                    ],
                 ),
-            ]
+            ],
         );
         $expected->fromSchema                        = $schema1;
         $expected->changedTables['bugdb']->fromTable = $schema1->getTable('bugdb');
@@ -449,7 +449,7 @@ class ComparatorTest extends TestCase
                 ],
                 [
                     'primary' => new Index('primary', ['integercolumn1', 'integercolumn2'], true),
-                ]
+                ],
             ),
         ]);
         $schema2 = new Schema([
@@ -461,7 +461,7 @@ class ComparatorTest extends TestCase
                 ],
                 [
                     'primary' => new Index('primary', ['integercolumn2', 'integercolumn1'], true),
-                ]
+                ],
             ),
         ]);
 
@@ -476,9 +476,9 @@ class ComparatorTest extends TestCase
                     [],
                     [
                         'primary' => new Index('primary', ['integercolumn2', 'integercolumn1'], true),
-                    ]
+                    ],
                 ),
-            ]
+            ],
         );
         $expected->fromSchema                        = $schema1;
         $expected->changedTables['bugdb']->fromTable = $schema1->getTable('bugdb');
@@ -668,7 +668,7 @@ class ComparatorTest extends TestCase
 
         self::assertEquals(
             $tableDiff,
-            $this->comparator->diffTable($tableA, $tableB)
+            $this->comparator->diffTable($tableA, $tableB),
         );
     }
 
@@ -843,9 +843,7 @@ class ComparatorTest extends TestCase
         self::assertSame($diff->changedSequences[0], $schemaNew->getSequence('baz'));
     }
 
-    /**
-     * @psalm-suppress NullArgument
-     */
+    /** @psalm-suppress NullArgument */
     public function testDiffDecimalWithNullPrecision(): void
     {
         $column = new Column('foo', Type::getType('decimal'));
@@ -1176,16 +1174,14 @@ class ComparatorTest extends TestCase
         $column2 = new Column(
             'foo',
             Type::getType('guid'),
-            ['notnull' => false, 'length' => '36', 'fixed' => true, 'default' => 'NEWID()', 'comment' => 'GUID 2.']
+            ['notnull' => false, 'length' => '36', 'fixed' => true, 'default' => 'NEWID()', 'comment' => 'GUID 2.'],
         );
 
         self::assertEquals(['notnull', 'default', 'comment'], $this->comparator->diffColumn($column1, $column2));
         self::assertEquals(['notnull', 'default', 'comment'], $this->comparator->diffColumn($column2, $column1));
     }
 
-    /**
-     * @dataProvider getCompareColumnComments
-     */
+    /** @dataProvider getCompareColumnComments */
     public function testCompareColumnComments(?string $comment1, ?string $comment2, bool $equals): void
     {
         $column1 = new Column('foo', Type::getType('integer'), ['comment' => $comment1]);
@@ -1202,9 +1198,7 @@ class ComparatorTest extends TestCase
         self::assertSame($expectedDiff, $actualDiff);
     }
 
-    /**
-     * @return mixed[][]
-     */
+    /** @return mixed[][] */
     public static function getCompareColumnComments(): iterable
     {
         return [
@@ -1245,7 +1239,7 @@ class ComparatorTest extends TestCase
                 'table1',
                 [
                     'id' => new Column('id', Type::getType('integer')),
-                ]
+                ],
             ),
             'table2' => new Table(
                 'table2',
@@ -1257,7 +1251,7 @@ class ComparatorTest extends TestCase
                 [],
                 [
                     new ForeignKeyConstraint(['id_table1'], 'table1', ['id'], 'fk_table2_table1'),
-                ]
+                ],
             ),
         ]);
         $toSchema   = new Schema([
@@ -1271,13 +1265,13 @@ class ComparatorTest extends TestCase
                 [],
                 [
                     new ForeignKeyConstraint(['id_table3'], 'table3', ['id'], 'fk_table2_table3'),
-                ]
+                ],
             ),
             'table3' => new Table(
                 'table3',
                 [
                     'id' => new Column('id', Type::getType('integer')),
-                ]
+                ],
             ),
         ]);
         $actual     = $this->comparator->compareSchemas($fromSchema, $toSchema);
@@ -1303,9 +1297,9 @@ class ComparatorTest extends TestCase
                     'a_table',
                     [
                         new Column('is_default', Type::getType('string')),
-                    ]
+                    ],
                 ),
-            ]
+            ],
         );
         $toSchema   = new Schema(
             [
@@ -1313,15 +1307,15 @@ class ComparatorTest extends TestCase
                     'a_table',
                     [
                         new Column('is_default', Type::getType('string'), ['columnDefinition' => 'ENUM(\'default\')']),
-                    ]
+                    ],
                 ),
-            ]
+            ],
         );
 
         self::assertEmpty(
             $this->comparator->compareSchemas($fromSchema, $toSchema)
                 ->changedTables,
-            'Schema diff is empty, since only `columnDefinition` changed from `null` (not detected) to a defined one'
+            'Schema diff is empty, since only `columnDefinition` changed from `null` (not detected) to a defined one',
         );
     }
 
