@@ -19,33 +19,6 @@ class MySQLSchemaTest extends TestCase
         $this->platform = new MySQLPlatform();
     }
 
-    /**
-     * @dataProvider comparatorProvider
-     */
-    public function testSwitchPrimaryKeyOrder(Comparator $comparator): void
-    {
-        $tableOld = new Table('test');
-        $tableOld->addColumn('foo_id', 'integer');
-        $tableOld->addColumn('bar_id', 'integer');
-        $tableNew = clone $tableOld;
-
-        $tableOld->setPrimaryKey(['foo_id', 'bar_id']);
-        $tableNew->setPrimaryKey(['bar_id', 'foo_id']);
-
-        $diff = $comparator->diffTable($tableOld, $tableNew);
-        self::assertNotFalse($diff);
-
-        $sql = $this->platform->getAlterTableSQL($diff);
-
-        self::assertEquals(
-            [
-                'DROP INDEX `primary` ON test',
-                'ALTER TABLE test ADD PRIMARY KEY (bar_id, foo_id)',
-            ],
-            $sql
-        );
-    }
-
     public function testGenerateForeignKeySQL(): void
     {
         $tableOld = new Table('test');
@@ -62,13 +35,11 @@ class MySQLSchemaTest extends TestCase
                 'ALTER TABLE test ADD CONSTRAINT FK_D87F7E0C8E48560F FOREIGN KEY (foo_id)'
                     . ' REFERENCES test_foreign (foo_id)',
             ],
-            $sqls
+            $sqls,
         );
     }
 
-    /**
-     * @dataProvider comparatorProvider
-     */
+    /** @dataProvider comparatorProvider */
     public function testClobNoAlterTable(Comparator $comparator): void
     {
         $tableOld = new Table('test');
@@ -85,13 +56,11 @@ class MySQLSchemaTest extends TestCase
 
         self::assertEquals(
             ['ALTER TABLE test ADD PRIMARY KEY (id)'],
-            $sql
+            $sql,
         );
     }
 
-    /**
-     * @return iterable<string,array{Comparator}>
-     */
+    /** @return iterable<string,array{Comparator}> */
     public static function comparatorProvider(): iterable
     {
         yield 'Generic comparator' => [
@@ -106,7 +75,7 @@ class MySQLSchemaTest extends TestCase
                     {
                         return null;
                     }
-                }
+                },
             ),
         ];
     }
