@@ -39,7 +39,7 @@ class ObjectTest extends TestCase
         $this->expectException(ConversionException::class);
         $this->expectExceptionMessage(
             "Could not convert database value to 'object' as an error was triggered by the unserialization:"
-                . " 'unserialize(): Error at offset 0 of 7 bytes'"
+                . " 'unserialize(): Error at offset 0 of 7 bytes'",
         );
         $this->type->convertToPHPValue('abcdefg', $this->platform);
     }
